<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Vedhak_Elementor_Blog extends Widget_Base {

	public function get_name() {
		return 'vedhak_elementor_blog';
	}

	public function get_title() {
		return esc_html__( 'Blog', 'vedhak' );
	}

	public function get_icon() {
		return 'eicon-post-list';
	}

	public function get_categories() {
		return [ 'vedhak' ];
	}

	public function get_script_depends() {
		return [ '' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		$args = array(
			'orderby' => 'name',
			'order' => 'ASC'
		);

		$categories 	= get_categories($args);
		$cate_array 	= array( 'all' => esc_html__( 'All categories', 'vedhak' ) );

		if ($categories) {
			foreach ( $categories as $cate ) {
				$cate_array[$cate->slug] = $cate->cat_name;
			}
		} else {
			$cate_array[ esc_html__( 'No content Category found', 'vedhak' ) ] = 0;
		}

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'vedhak' ),
			]
		);	

			$this->add_control(
				'template',
				[
					'label' => esc_html__( 'Template', 'vedhak' ),
					'type' => Controls_Manager::SELECT,
					'default' => 'template1',
					'options' => [
						'template1' => esc_html__( 'Template 1', 'vedhak' ),
						'template2' => esc_html__( 'Template 2', 'vedhak' ),
						'template3' => esc_html__( 'Template 3', 'vedhak' ),
					]
				]
			);
			
			$this->add_control(
				  'category',
				[
					'label' => esc_html__( 'Category', 'vedhak' ),
					'type' => Controls_Manager::SELECT,
					'default' => 'all',
					'options' => $cate_array
				]
			);
  
			$this->add_control(
				'total_count',
				[
					'label' => esc_html__( 'Post Total', 'vedhak' ),
					'type' => Controls_Manager::NUMBER,
					'default' => 3,
				]
			);
  
			$this->add_control(
				'number_column',
				[
					'label' => esc_html__( 'Columns', 'vedhak' ),
					'type' => Controls_Manager::SELECT,
					'default' => 'column_3',
					'options' => [
						'column_2' => esc_html__( '2 Columns', 'vedhak' ),
						'column_3' => esc_html__( '3 Columns', 'vedhak' ),
						'column_4' => esc_html__( '4 Columns', 'vedhak' ),
					],
				]
			);
  
			$this->add_control(
				'order',
				[
					'label' => esc_html__('Order', 'vedhak'),
					'type' => Controls_Manager::SELECT,
					'default' => 'desc',
					'options' => [
						'asc' => esc_html__('Ascending', 'vedhak'),
						'desc' => esc_html__('Descending', 'vedhak'),
					]
				]
			);

			$this->add_control(
				'order_by',
				[
					'label' 	=> esc_html__('Order By', 'vedhak'),
					'type' 		=> \Elementor\Controls_Manager::SELECT,
					'default' 	=> 'ID',
					'options' 	=> [
						'none' => esc_html__('None', 'vedhak'),
						'ID' 	=> esc_html__('ID', 'vedhak'),
						'title' => esc_html__('Title', 'vedhak'),
						'date' 	=> esc_html__('Date', 'vedhak'),
						'modified' => esc_html__('Modified', 'vedhak'),
						'rand' 	=> esc_html__('Rand', 'vedhak'),
					]
				]
			);
  
			$this->add_control(
				'show_category',
				[
					'label' => esc_html__( 'Show Category', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => esc_html__( 'Show', 'vedhak' ),
					'label_off' => esc_html__( 'Hide', 'vedhak' ),
					'return_value' => 'yes',
					'default' => 'yes',
					'condition' => [
						'template!' => 'template1',
					],
				]
			);
  
			$this->add_control(
				'show_comment',
				[
					'label' => esc_html__( 'Show Comment', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => esc_html__( 'Show', 'vedhak' ),
					'label_off' => esc_html__( 'Hide', 'vedhak' ),
					'return_value' => 'yes',
					'default' => 'yes',
					'condition' => [
				 		'template!' => 'template3',
				 	],
				]
			);

			$this->add_control(
				'show_author',
			 	[
					'label' => esc_html__( 'Show Author', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => esc_html__( 'Show', 'vedhak' ),
					'label_off' => esc_html__( 'Hide', 'vedhak' ),
					'return_value' => 'yes',
				 	'default' => 'yes',
				 	'condition' => [
				 		'template' => 'template3',
				 	],
				]
			);
  
			$this->add_control(
				'show_date',
				[
					'label' => esc_html__( 'Show Date', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => esc_html__( 'Show', 'vedhak' ),
					'label_off' => esc_html__( 'Hide', 'vedhak' ),
					'return_value' => 'yes',
					'default' => 'yes',
				]
			);
 
			$this->add_control(
				'show_title',
				[
					'label' => esc_html__( 'Show Title', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => esc_html__( 'Show', 'vedhak' ),
					'label_off' => esc_html__( 'Hide', 'vedhak' ),
					'return_value' => 'yes',
					'default' => 'yes',
				]
			);

			$this->add_control(
				'show_divider',
				[
					'label' => esc_html__( 'Show Divider', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => esc_html__( 'Show', 'vedhak' ),
					'label_off' => esc_html__( 'Hide', 'vedhak' ),
					'return_value' => 'yes',
					'default' => 'yes',
					'condition' => [
				 		'template' => 'template3',
				 	],
				]
			);
  
			$this->add_control(
				'show_read_more',
				[
					'label' => esc_html__( 'Show Read More', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => esc_html__( 'Show', 'vedhak' ),
					'label_off' => esc_html__( 'Hide', 'vedhak' ),
					'return_value' => 'yes',
					'default' => 'yes',
				]
			);

		$this->end_controls_section();

		$this->start_controls_section(
			'button_readmore_tab_content',
			[
				'label' => esc_html__( 'Button Readmore', 'vedhak' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
				'condition' => [
					'show_read_more' => 'yes',
				],
			]
		);

			$this->add_control(
				'text_readmore',
				[
					'label' => esc_html__( 'Text', 'vedhak' ),
					'type' => Controls_Manager::TEXT,
					'default' => esc_html__('Read More', 'vedhak'),
				]
			);

			$this->add_control(
				'button_readmore_icon',
				[
					'label' => esc_html__( 'Icon', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::ICONS,
					'default' => [
						'value' => 'fas fa-angle-double-right',
						'library' => 'fa-solid',
					],
				]
			);

		$this->end_controls_section();

		/* Begin General Style */
		$this->start_controls_section(
			'general',
			[
				'label' => esc_html__( 'General', 'vedhak' ),
				'tab' 	=> Controls_Manager::TAB_STYLE,
			]
		);
  
			$this->add_responsive_control(
				'general_align',
				[
					'label' 	=> esc_html__( 'Alignment', 'vedhak' ),
					'type' 		=> \Elementor\Controls_Manager::CHOOSE,
					'options' 	=> [
						'left' => [
							'title' => esc_html__( 'Left', 'vedhak' ),
							'icon' 	=> 'eicon-text-align-left',
						],
						'center' => [
							'title' => esc_html__( 'Center', 'vedhak' ),
							'icon' 	=> 'eicon-text-align-center',
						],
						'right' => [
							'title' => esc_html__( 'Right', 'vedhak' ),
							'icon' 	=> 'eicon-text-align-right',
						],
						  
					],
					'toggle' 	=> true,
					'selectors' => [
						'{{WRAPPER}} .ova-blog .item .content' => 'text-align: {{VALUE}};',
					],
				]
			);

		  	$this->add_responsive_control(
				'general_spacing',
				[
					'label' => esc_html__( 'Spacing', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 60,
							'step' => 1,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-blog' => 'gap: {{SIZE}}{{UNIT}};',
					],
				]
			);

		  	$this->add_responsive_control(
			  	'general_padding',
			  	[
				  	'label' => esc_html__( 'Padding', 'vedhak' ),
				  	'type' => Controls_Manager::DIMENSIONS,
				  	'size_units' => [ 'px', 'em', '%' ],
				  	'selectors' => [
					  	'{{WRAPPER}} .ova-blog .item .content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				  	],
			  	]
		  	);

		  	$this->add_group_control(
				\Elementor\Group_Control_Box_Shadow::get_type(),
				[
					'name' => 'general_box_shadow',
					'selector' => '{{WRAPPER}} .ova-blog .item',
				]
			);

		$this->end_controls_section();

		// IMAGE TAB
		$this->start_controls_section(
		'image_section',
		    [
			    'label' => esc_html__( 'Image', 'vedhak' ),
			    'tab' => \Elementor\Controls_Manager::TAB_STYLE,
		    ]
	    );

	    	$this->add_responsive_control(
				'image_height',
				[
					'label' => esc_html__( 'Height', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px' ],
					'range' => [
						'px' => [
							'min' => 300,
							'max' => 600,
							'step' => 1,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-blog.template3 .item , {{WRAPPER}}  .ova-blog .item .media .box-img a img' => 'min-height: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'image_border_radius',
				[
					'label' => esc_html__( 'Border Radius', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'selectors' => [
						'{{WRAPPER}} .ova-blog.template3 .item .media .box-img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
					'condition' => [
						'template' => 'template3',
					],
				]
			);

			$this->add_control(
				'overlay_heading',
				[
					'label' => esc_html__( 'Overlay', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
					'condition' => [
						'template' => 'template3',
					],
				]
			);

			$this->add_control(
				'image_overlay_border_radius',
				[
					'label' => esc_html__( 'Border Radius', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'selectors' => [
						'{{WRAPPER}} .ova-blog.template3 .item .media .box-img .overlay' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
					'condition' => [
						'template' => 'template3',
					],
				]
			);

			$this->start_controls_tabs(
				'image_tabs',
			);

				$this->start_controls_tab(
					'image_overlay_normal_tab',
					[
						'label' => esc_html__( 'Normal', 'vedhak' ),
						'condition' => [
							'template' => 'template3',
						],
					]
				);

					$this->add_control(
						'image_overlay_background_color',
						[
							'label' => esc_html__( 'Background Color', 'vedhak' ),
							'type' => \Elementor\Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-blog .item .media .box-img .overlay' => 'background-color: {{VALUE}}',
							],
							'condition' => [
								'template' => 'template3',
							],
						]
					);

					$this->add_control(
						'image_overlay_opacity_normal',
						[
							'label' => esc_html__( 'Opacity', 'vedhak' ),
							'type' => \Elementor\Controls_Manager::SLIDER,
							'size_units' => [ 'px' ],
							'range' => [
								'px' => [
									'min' => 0,
									'max' => 1,
									'step' => 0.01,
								],
							],
							'selectors' => [
								'{{WRAPPER}} .ova-blog.template3 .item .media .box-img .overlay' => 'opacity: {{SIZE}};',
							],
							'condition' => [
								'template' => 'template3',
							],
						]
					);

				$this->end_controls_tab();

				$this->start_controls_tab(
					'image_overlay_hover_tab',
					[
						'label' => esc_html__( 'Hover', 'vedhak' ),
						'condition' => [
							'template' => 'template3',
						],
					]
				);

					$this->add_control(
						'image_overlay_background_color_hover',
						[
							'label' => esc_html__( 'Background Color', 'vedhak' ),
							'type' => \Elementor\Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-blog .item:hover .media .box-img .overlay' => 'background-color: {{VALUE}}',
							],
							'condition' => [
								'template' => 'template3',
							],
						]
					);

					$this->add_control(
						'image_overlay_opacity_hover',
						[
							'label' => esc_html__( 'Opacity', 'vedhak' ),
							'type' => \Elementor\Controls_Manager::SLIDER,
							'size_units' => [ 'px' ],
							'range' => [
								'px' => [
									'min' => 0,
									'max' => 1,
									'step' => 0.01,
								],
							],
							'selectors' => [
								'{{WRAPPER}} .ova-blog.template3 .item:hover .media .box-img .overlay' => 'opacity: {{SIZE}};',
							],
							'condition' => [
								'template' => 'template3',
							],
						]
					);

				$this->end_controls_tab();

			$this->end_controls_tabs();

	    $this->end_controls_section();

		// CATEGORY TAB
		$this->start_controls_section(
		'category_section',
		    [
			    'label' => esc_html__( 'Category', 'vedhak' ),
			    'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			    'condition' => [
					'template!' => 'template1',
				],
		    ]
	    );

			$this->add_group_control(
			    \Elementor\Group_Control_Typography::get_type(),
			    [
				    'name' => 'category_typography',
				    'selector' => '{{WRAPPER}} .ova-blog .item .category', 
			    ]
		    );

		    $this->add_control(
			    'category_color',
			    [
				    'label' => esc_html__( 'Color', 'vedhak' ),
				    'type' => \Elementor\Controls_Manager::COLOR,
				    'selectors' => [
					    '{{WRAPPER}} .ova-blog .item .category' => 'color : {{VALUE}};',
				    ],
			    ]
		    );
  
			$this->add_control(
				'odd_category_background_color',
				 	[
					  	'label' => esc_html__( 'Background Odd Item', 'vedhak' ),
					  	'type' => \Elementor\Controls_Manager::COLOR,
					  	'selectors' => [
						  '{{WRAPPER}} .ova-blog .item:nth-child(odd) .category' => 'background-color : {{VALUE}};',
					],
					'condition' => [
				  		'template' => 'template2',
				  	],
				]
			);

			$this->add_control(
			  	'even_category_background_color',
			  	[
				  	'label' => esc_html__( 'Background Even Item', 'vedhak' ),
				 	'type' => \Elementor\Controls_Manager::COLOR,
				  	'selectors' => [
					  	'{{WRAPPER}} .ova-blog .item:nth-child(even) .category' => 'background-color : {{VALUE}};',
				  	],
				  	'condition' => [
				  		'template' => 'template2',
				  	],
			  	]
			);

			$this->add_control(
				'category_background_color',
				 	[
					  	'label' => esc_html__( 'Background Color', 'vedhak' ),
					  	'type' => \Elementor\Controls_Manager::COLOR,
					  	'selectors' => [
						  '{{WRAPPER}} .ova-blog .item .category' => 'background-color : {{VALUE}};',
					],
					'condition' => [
				  		'template' => 'template3',
				  	],
				]
			);

			$this->add_control(
				'category_background_color_hover',
				 	[
					  	'label' => esc_html__( 'Background Color Hover', 'vedhak' ),
					  	'type' => \Elementor\Controls_Manager::COLOR,
					  	'selectors' => [
						  '{{WRAPPER}} .ova-blog .item:hover .category' => 'background-color : {{VALUE}};',
					],
					'condition' => [
				  		'template' => 'template3',
				  	],
				]
			);

			$this->add_responsive_control(
				'category_padding',
				[
					'label' => esc_html__( 'Padding', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'selectors' => [
						'{{WRAPPER}} .ova-blog .item .category' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'category_margin',
				[
					'label' => esc_html__( 'Margin', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'selectors' => [
						'{{WRAPPER}} .ova-blog .item .category' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'category_border_radius',
				[
					'label' => esc_html__( 'Border Radius', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'selectors' => [
						'{{WRAPPER}} .ova-blog .item .category' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'category_position_heading',
				[
					'label' => esc_html__( 'Position', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
					'condition' => [
						'template' => 'template2',
					],
				]
			);

			$this->add_responsive_control(
				'category_position_right',
				[
					'label' => esc_html__( 'Right', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1000,
							'step' => 1,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-blog .item .category' => 'right: {{SIZE}}{{UNIT}};',
					],
					'condition' => [
						'template' => 'template2',
					],
				]
			);

			$this->add_responsive_control(
				'category_position_bottom',
				[
					'label' => esc_html__( 'Bottom', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1000,
							'step' => 1,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-blog .item .category' => 'bottom: {{SIZE}}{{UNIT}};',
					],
					'condition' => [
						'template' => 'template2',
					],
				]
			);

	    $this->end_controls_section();

		// DATE TAB
		$this->start_controls_section(
			'date_section',
			    [
				    'label' => esc_html__( 'Date', 'vedhak' ),
				    'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			    ]
		    );

	    	$this->add_responsive_control(
				'date_margin',
				[
					'label' => esc_html__( 'Margin', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'selectors' => [
						'{{WRAPPER}} .ova-blog.template3 .item .content .bottom-content .post-time , {{WRAPPER}}  .ova-blog .item .content .post-meta .item-meta.post-time' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'date_icon_heading',
				[
					'label' => esc_html__( 'Icon', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

			$this->add_responsive_control(
				'date_icon_size',
				[
					'label' => esc_html__( 'Size', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 200,
							'step' => 1,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						' {{WRAPPER}} .ova-blog .item .content .post-time .icon-time i' => 'font-size: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
			    'date_icon_color',
			    [
				    'label' => esc_html__( 'Color', 'vedhak' ),
				    'type' => \Elementor\Controls_Manager::COLOR,
				    'selectors' => [
					    '{{WRAPPER}} .ova-blog .item .content .post-time .icon-time i' => 'color : {{VALUE}};',
				    ],
			    ]
		    );

		    $this->add_control(
			    'date_icon_color_hover',
			    [
				    'label' => esc_html__( 'Color Hover', 'vedhak' ),
				    'type' => \Elementor\Controls_Manager::COLOR,
				    'selectors' => [
					    '{{WRAPPER}} .ova-blog.template3 .item:hover .content .bottom-content .post-time .icon-time i' => 'color : {{VALUE}};',
				    ],
				    'condition' => [
						'template' => 'template3',
					],
			    ]
		    );

		    $this->add_responsive_control(
				'date_icon_margin',
				[
					'label' => esc_html__( 'Margin', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'selectors' => [
						' {{WRAPPER}} .ova-blog .item .content .post-time .icon-time' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'date_text_heading',
				[
					'label' => esc_html__( 'Text', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

			$this->add_group_control(
			    \Elementor\Group_Control_Typography::get_type(),
			    [
				    'name' => 'date_typography',
				    'selector' => '{{WRAPPER}} .ova-blog .item .content .post-time .post-date ', 
			    ]
		    );

		    $this->add_control(
			    'date_color',
			    [
				    'label' => esc_html__( 'Color', 'vedhak' ),
				    'type' => \Elementor\Controls_Manager::COLOR,
				    'selectors' => [
					    '{{WRAPPER}} .ova-blog .item .content .post-time .post-date ' => 'color : {{VALUE}};',
				    ],
			    ]
		    );
  
			$this->add_control(
				'date_color_hover',
				[
					'label' => esc_html__( 'Color Hover', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-blog.template3 .item:hover .content .bottom-content .post-time .post-date ' => 'color : {{VALUE}};',
					],
					'condition' => [
						'template' => 'template3',
					],
				]
			);
			
		$this->end_controls_section(); 
		// END DATE Tab

		// END AUTHOR Tab
		$this->start_controls_section(
			'section_author',
			    [
				    'label' => esc_html__( 'Author', 'vedhak' ),
				    'tab' => \Elementor\Controls_Manager::TAB_STYLE,
				    'condition' => [
				    	'template' => 'template3',
				    ],
			    ]
			);

			$this->add_responsive_control(
				'author_margin',
				[
					'label' => esc_html__( 'Margin', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'selectors' => [
						'{{WRAPPER}} .ova-blog.template3 .item .content .top-content .author' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'author_image_heading',
				[
					'label' => esc_html__( 'Image', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

			$this->add_responsive_control(
				'author_image_size',
				[
					'label' => esc_html__( 'Size', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 200,
							'step' => 1,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-blog.template3 .item .content .top-content .author .image img' => 'min-width: {{SIZE}}{{UNIT}};width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'author_image_margin',
				[
					'label' => esc_html__( 'Margin', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'selectors' => [
						'{{WRAPPER}} .ova-blog.template3 .item .content .top-content .author .image' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'author_image_border_radius',
				[
					'label' => esc_html__( 'Border Radius', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'selectors' => [
						'{{WRAPPER}} .ova-blog.template3 .item .content .top-content .author .image img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'author_info_heading',
				[
					'label' => esc_html__( 'Name', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'author_info_typography',
					'selector' => '{{WRAPPER}} .ova-blog.template3 .item .content .top-content .author .name a',
				]
			);

			$this->add_control(
				'author_info_color',
				[
					'label' => esc_html__( 'Color', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-blog.template3 .item .content .top-content .author .name a' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_control(
				'author_info_color_hover',
				[
					'label' => esc_html__( 'Hover Color', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-blog.template3 .item:hover .content .top-content .author .name a' => 'color: {{VALUE}}',
					],
				]
			);

		$this->end_controls_section();

		$this->start_controls_section(
		'section_comment',
		    [
			    'label' => esc_html__( 'Comment', 'vedhak' ),
			    'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			    'condition' => [
			    	'template!' => 'template3',
			    ],
		    ]
		);

			$this->add_responsive_control(
				'comment_margin',
				[
					'label' => esc_html__( 'Margin', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'selectors' => [
						'{{WRAPPER}} .ova-blog .item .content .post-meta .item-meta.post-comment' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'comment_icon_heading',
				[
					'label' => esc_html__( 'Icon', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

			$this->add_responsive_control(
				'comment_icon_size',
				[
					'label' => esc_html__( 'Size', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 200,
							'step' => 1,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-blog .item .content .post-meta .item-meta.post-comment .left i' => 'font-size: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'icon_comment_color',
				[
					'label' => esc_html__( 'Icon Color', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-blog .item .content .post-meta .item-meta.post-comment .left i' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_control(
				'comment_text_heading',
				[
					'label' => esc_html__( 'Text', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'comment_typography',
					'selector' => '{{WRAPPER}} .ova-blog .item .content .post-comment .right a',
				]
			);

			$this->add_control(
				'link_comment_color',
				[
					'label' => esc_html__( 'Link Color', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-blog .item .content .post-meta .item-meta.post-comment .right a' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_control(
				'comment_color_hover',
				[
					'label' => esc_html__( 'Link Color Hover', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-blog .item .content .post-meta .item-meta.post-comment .right a:hover' => 'color: {{VALUE}}',
					],
				]
			);

		$this->end_controls_section();

		//SECTION TAB STYLE TITLE
		  	$this->start_controls_section(
			  	'section_title',
			  	[
				  	'label' => esc_html__( 'Title', 'vedhak' ),
				  	'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			  	]
		  	);
  
				$this->add_group_control(
					\Elementor\Group_Control_Typography::get_type(),
					[
						'name' => 'title_typography',
						'selector' => '{{WRAPPER}} .ova-blog .item .content .post-title a',
					]
				);
  
				$this->add_control(
					  'color_title',
					  [
						  'label' => esc_html__( 'Color', 'vedhak' ),
						  'type' => \Elementor\Controls_Manager::COLOR,
						  'selectors' => [
							  '{{WRAPPER}} .ova-blog .item .content .post-title a' => 'color : {{VALUE}};',
						  ],
					  ]
				);
		  
				$this->add_control(
					  'color_title_hover',
					  [
						  'label' => esc_html__( 'Color Hover', 'vedhak' ),
						  'type' => \Elementor\Controls_Manager::COLOR,
						  'selectors' => [
							  '{{WRAPPER}} .ova-blog .item .content .post-title a:hover ' => 'color : {{VALUE}};',
						  ],
					  ]
				);
		  
				$this->add_responsive_control(
					  'margin_title',
					  [
						  'label' => esc_html__( 'Margin', 'vedhak' ),
						  'type' => \Elementor\Controls_Manager::DIMENSIONS,
						  'size_units' => [ 'px', 'em', '%' ],
						  'selectors' => [
							  '{{WRAPPER}} .ova-blog .item .content .post-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						  ],
					  ]
				);
  
		    $this->end_controls_section();

		    // Start Divider Tab
			$this->start_controls_section(
				'section_divider',
				    [
					    'label' => esc_html__( 'Divider', 'vedhak' ),
					    'tab' => \Elementor\Controls_Manager::TAB_STYLE,
					    'condition' => [
					    	'template' => 'template3',
					    ],
				    ]
				);

				$this->add_responsive_control(
					'divider_width',
					[
						'label' => esc_html__( 'Width', 'vedhak' ),
						'type' => \Elementor\Controls_Manager::SLIDER,
						'size_units' => [ 'px', '%' ],
						'range' => [
							'px' => [
								'min' => 0,
								'max' => 1000,
								'step' => 1,
							],
							'%' => [
								'min' => 0,
								'max' => 100,
							],
						],
						'selectors' => [
							' {{WRAPPER}} .ova-blog.template3 .item .content .bottom-content .divider' => 'width: {{SIZE}}{{UNIT}};',
						],
					]
				);

				$this->add_responsive_control(
					'divider_height',
					[
						'label' => esc_html__( 'Height', 'vedhak' ),
						'type' => \Elementor\Controls_Manager::SLIDER,
						'size_units' => [ 'px', '%' ],
						'range' => [
							'px' => [
								'min' => 0,
								'max' => 100,
								'step' => 1,
							],
							'%' => [
								'min' => 0,
								'max' => 100,
							],
						],
						'selectors' => [
							' {{WRAPPER}} .ova-blog.template3 .item .content .bottom-content .divider' => 'height: {{SIZE}}{{UNIT}};',
						],
					]
				);

				$this->add_control(
					'divider_color',
					[
						'label' => esc_html__( 'Color', 'vedhak' ),
						'type' => \Elementor\Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ova-blog.template3 .item .content .bottom-content .divider' => 'background-color : {{VALUE}};',
						],
					]
				);

				$this->add_control(
					'divider_color_hover',
					[
						'label' => esc_html__( 'Color Hover', 'vedhak' ),
						'type' => \Elementor\Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ova-blog.template3 .item:hover .content .bottom-content .divider' => 'background-color : {{VALUE}};',
						],
					]
				);

				$this->add_responsive_control(
					'divider_margin',
					[
						'label' => esc_html__( 'Margin', 'vedhak' ),
						'type' => \Elementor\Controls_Manager::DIMENSIONS,
						'size_units' => [ 'px', '%', 'em', 'rem' ],
						'selectors' => [
							'{{WRAPPER}} .ova-blog.template3 .item .content .bottom-content .divider' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
					]
				);

			$this->end_controls_section();
			//End TAB STYLE DIVIDER
	  
		    //SECTION TAB STYLE READMORE
		    $this->start_controls_section(
			    'section_readmore',
			    [
				    'label' => esc_html__( 'Read More', 'vedhak' ),
				    'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			    ]
		    );

				$this->add_control(
					'color_read_more',
					[
						'label' => esc_html__( 'Color', 'vedhak' ),
						'type' => \Elementor\Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ova-blog .item .content .read-more a' => 'color : {{VALUE}};',
						],
					]
				);

				$this->add_control(
					'color_read_more_hover',
					[
						'label' => esc_html__( 'Color Hover', 'vedhak' ),
						'type' => \Elementor\Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ova-blog .item .content .read-more:hover a' => 'color : {{VALUE}};',
						],
					]
				);
  
			  	$this->add_responsive_control(
				  	'margin_read_more',
					[
						'label' => esc_html__( 'Margin', 'vedhak' ),
						'type' => \Elementor\Controls_Manager::DIMENSIONS,
						'size_units' => [ 'px', 'em', '%' ],
						'selectors' => [
							'{{WRAPPER}} .ova-blog .item .content .read-more' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
					]
				);

				$this->add_control(
					'readmore_icon_heading',
					[
						'label' => esc_html__( 'Icon', 'vedhak' ),
						'type' => \Elementor\Controls_Manager::HEADING,
						'separator' => 'before',
					]
				);

			  	$this->add_responsive_control(
					'readmore_icon_size',
					[
						'label' => esc_html__( 'Size', 'vedhak' ),
						'type' => \Elementor\Controls_Manager::SLIDER,
						'size_units' => [ 'px', '%' ],
						'range' => [
							'px' => [
								'min' => 0,
								'max' => 200,
								'step' => 1,
							],
							'%' => [
								'min' => 0,
								'max' => 100,
							],
						],
						'selectors' => [
							'{{WRAPPER}} .ova-blog .item .content .read-more a .icon i' => 'font-size: {{SIZE}}{{UNIT}};',
						],
					]
				);

			  	$this->add_control(
					'readmore_text_heading',
					[
						'label' => esc_html__( 'Text', 'vedhak' ),
						'type' => \Elementor\Controls_Manager::HEADING,
						'separator' => 'before',
					]
				);

			  	$this->add_group_control(
					\Elementor\Group_Control_Typography::get_type(),
					[
					  'name' => 'readmore_text_typography',
					  'selector' => '{{WRAPPER}} .ova-blog .item .content .read-more a', 
					]
				);

				$this->add_responsive_control(
				  	'margin_read_more_text',
					[
						'label' => esc_html__( 'Margin', 'vedhak' ),
						'type' => \Elementor\Controls_Manager::DIMENSIONS,
						'size_units' => [ 'px', 'em', '%' ],
						'selectors' => [
							'{{WRAPPER}} .ova-blog .item .content .read-more a .text' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
					]
				);

		  $this->end_controls_section();
	}

	// Render Template Here
	protected function render() {
		$settings = $this->get_settings();

		$template 					= 	$settings['template'];

		$category 					= 	$settings['category'];
		$total_count 				= 	$settings['total_count'];
		$order 						= 	$settings['order'];
		$order_by 					= 	$settings['order_by'];
		$number_column 				= 	$settings['number_column'];

		$show_category      		=   $settings['show_category'];
		$show_date 					= 	$settings['show_date'];
		$show_author 				= 	$settings['show_author'];
		$show_title 				= 	$settings['show_title'];
		$show_comment 				= 	$settings['show_comment'];
		$show_divider 				= 	$settings['show_divider'];
		$show_read_more				= 	$settings['show_read_more'];

		$text_readmore 				= 	$settings['text_readmore'];
		$button_readmore_icon 		= 	$settings['button_readmore_icon'];

		$args = [];
			
		if ($category == 'all') {
		  	$args = [
			  	'post_type' 		=> 'post',
			  	'post_status'       => 'publish',
			  	'posts_per_page' 	=> $total_count,
			  	'order' 			=> $order,
			  	'orderby' 			=> $order_by,
		  	];
		} else {
		  	$args = [
			  	'post_type' 		=> 'post',
			  	'post_status'       => 'publish',
			  	'category_name'		=>	$category,
			  	'posts_per_page' 	=> 	$total_count,
			  	'order' 			=> 	$order,
			  	'orderby' 			=>  $order_by,
			  	'fields'			=> 	'ids'
		  	];
		}

		$blog = new \WP_Query($args);
		?>

			<ul class="ova-blog ova-<?php echo esc_attr( $number_column ); ?> <?php echo esc_attr( $template ); ?>">
				<?php
				  	if($blog->have_posts()) : while($blog->have_posts()) : $blog->the_post();
			  	?>
			  		<?php if( $template != 'template3') : ?>
				  	<li class="item">

				  		<div class="media">

						  	<?php
						  	    $post_id   = get_the_ID();
							  	$thumbnail = wp_get_attachment_image_url(get_post_thumbnail_id() , 'vedhak_thumbnail' );
							  	$url_thumb = $thumbnail ? $thumbnail : \Elementor\Utils::get_placeholder_image_src();
						  	?>
						  	<div class="box-img">

						  		<a href="<?php the_permalink(); ?>" rel="bookmark" title="<?php the_title_attribute(); ?>">
								  	<img src="<?php echo esc_url( $url_thumb ) ?>" alt="<?php the_title(); ?>">
							  	</a>

							  	<div class="overlay"></div>

						  	</div>

							<?php $categories = get_the_category();

								if ( ! empty( $categories ) && $show_category =='yes' && $template != 'template1' ) { ?>

									<p class="category"><?php echo esc_html( $categories[0]->name ); ?></p>

							<?php } ?>

					  	</div>

					  	<div class="content">

					  		<ul class="post-meta">

								<?php if( $show_date == 'yes' ){ ?>
									<li class="item-meta post-time">
										<span class="icon-time">
										  	<i class="ovaicon-calendar-1"></i>
									  	</span>
									  	<span class="post-date">
										  	<?php the_time('F j,Y');?>
									  	</span>
								  	</li>
								<?php  } ?>

							  	<?php if( $show_comment == 'yes' ): ?>
								  	<li class="item-meta  post-comment">
									  	<span class="left comment">
										  	<i class="ovaicon ovaicon-comment-1"></i>
									  	</span>
									  	<span class="right comment">
										  	<?php
										  		comments_popup_link(
											  	esc_html__('0 Comments', 'vedhak'), 
											  	esc_html__('1 Comments', 'vedhak'), 
											  	'%',
											  	'Comments',
											  	esc_html__( 'Comment off', 'vedhak' ) )
										  	; ?> 
									  	</span>            
								  	</li>
							  	<?php endif; ?>

						  	</ul>
					  		
					  		<?php if( $show_title == 'yes' ){ ?>

								<h2 class="post-title">

									<a href="<?php the_permalink(); ?>" rel="bookmark" title="<?php the_title_attribute(); ?>">
										<?php the_title(); ?>
									</a>

								</h2>

							<?php } ?>

							<?php if( $show_read_more == 'yes' ){ ?>	

								<div class="read-more" >

									<a href="<?php the_permalink(); ?>">
										<span class="text"><?php echo esc_html( $text_readmore ); ?></span>
										<span class="icon"><i class="<?php echo esc_attr( $button_readmore_icon['value'] ); ?>"></i></span>		
									</a>

								</div>

							<?php }?>	

					  	</div>
				  		
				  	</li>
				  	<?php endif; ?>

				  	<?php if( $template == 'template3') : ?>

				  		<li class="item">

					  		<div class="media">

							  	<?php
							  	    $post_id   = get_the_ID();
								  	$thumbnail = wp_get_attachment_image_url(get_post_thumbnail_id() , 'vedhak_thumbnail' );
								  	$url_thumb = $thumbnail ? $thumbnail : \Elementor\Utils::get_placeholder_image_src();
							  	?>
							  	<div class="box-img">

							  		<a href="<?php the_permalink(); ?>" rel="bookmark" title="<?php the_title_attribute(); ?>">
									  	<img src="<?php echo esc_url( $url_thumb ) ?>" alt="<?php the_title(); ?>">
								  	</a>

								  	<div class="overlay"></div>

							  	</div>
								
						  	</div>

						  	<div class="content">

						  		<div class="top-content">

						  			<?php $categories = get_the_category();

										if ( ! empty( $categories ) && $show_category =='yes' && $template != 'template1' ) { ?>

											<p class="category"><?php echo esc_html( $categories[0]->name ); ?></p>

									<?php } ?>

									<?php if( $show_title == 'yes' ){ ?>
										<h2 class="post-title">
											<a href="<?php the_permalink(); ?>" rel="bookmark" title="<?php the_title_attribute(); ?>">
												<?php the_title(); ?>
											</a>
										</h2>
									<?php } ?>

								  	<?php if( $show_author == 'yes' ){ ?>
									    <div class="author">
										    <span class="image">
											     <?php  echo get_avatar(get_the_author_meta('ID')); ?>
										    </span>
										    <span class="name">
											  	<a href="<?php echo get_author_posts_url( get_the_author_meta( 'ID' ) ); ?>">
												  	<?php the_author_meta( 'display_name' ); ?>
											  	</a>
										    </span>
									    </div>
							  		<?php } ;?>

							  	</div>
						  		
							  	<div class="bottom-content">

							  		<?php if( $show_date == 'yes' ){ ?>

										<div class="post-time">

											<span class="icon-time">
											  	<i class="ovaicon-calendar-1"></i>
										  	</span>

										  	<span class="post-date">
											  	<?php the_time('F j,Y');?>
										  	</span>

									  	</div>

									<?php  } ?>

									<?php if( $show_divider == 'yes' ){ ?>
										<div class="divider"></div>
									<?php  } ?>

							  		<?php if( $show_read_more == 'yes' ){ ?>	

										<div class="read-more" >

											<a href="<?php the_permalink(); ?>">

												<span class="text"><?php echo esc_html( $text_readmore ); ?></span>
												<span class="icon"><i class="<?php echo esc_attr( $button_readmore_icon['value'] ); ?>"></i></span>	

											</a>

										</div>

									<?php }?>

							  	</div>
									
						  	</div>
					  		
					  	</li>

				  	<?php endif; ?>
				<?php
				  	endwhile; endif; wp_reset_postdata();
			    ?>
			</ul>

		<?php
	}
}
$widgets_manager->register( new Vedhak_Elementor_Blog() );