<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Vedhak_Elementor_Heading extends Widget_Base {

	public function get_name() {
		return 'vedhak_elementor_heading';
	}

	public function get_title() {
		return esc_html__( 'Ova Heading', 'vedhak' );
	}

	public function get_icon() {
		return 'eicon-heading';
	}

	public function get_categories() {
		return [ 'vedhak' ];
	}

	public function get_script_depends() {
		return [ '' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		$this->start_controls_section(
			'heading_section_content',
			[
				'label' => esc_html__( 'Heading', 'vedhak' ),
			]
		);	
			
			// Add Class control
			$this->add_control(
				'template',
				[
					'label' => esc_html__( 'Template', 'vedhak' ),
					'type' => Controls_Manager::SELECT,
					'default' => 'template1',
					'options' => [
						'template1' => esc_html__('Template 1 ', 'vedhak'),
						'template2' => esc_html__('Template 2 ', 'vedhak'),
					]
				]
			);

			$this->add_control(
				'number_prefix',
				[
					'label' => esc_html__( 'Number Prefix', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::TEXT,
					'default' => esc_html__( '01', 'vedhak' ),
					'placeholder' => esc_html__( 'Type number prefix here', 'vedhak' ),
					'condition' => [
						'template' => 'template1',
					],
				]
			);
			
			$this->add_control(
				'sub_title',
				[
					'label' 	=> esc_html__( 'Sub Title', 'vedhak' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> esc_html__( 'About Us', 'vedhak' ),
					'condition' => [
						'template' => 'template1',
					],
				]
			);

			$this->add_control(
				'title_bold',
				[
					'label' 	=> esc_html__( 'Title Bold', 'vedhak' ),
					'type' 		=> Controls_Manager::TEXTAREA,
					'default' 	=> esc_html__( 'We’re Most Trusted Travel ', 'vedhak' ), 
				]
			);

			$this->add_control(
				'title_normal',
				[
					'label' 	=> esc_html__( 'Title Normal', 'vedhak' ),
					'type' 		=> Controls_Manager::TEXTAREA,
					'default' 	=> esc_html__( ' Partner Around The World', 'vedhak' ),
				]
			);

			$this->add_control(
				'description',
				[
					'label' 	=> esc_html__( 'Description', 'vedhak' ),
					'type' 		=> Controls_Manager::TEXTAREA,
					'condition' => [
						'template' => 'template1',
					],
				]
			);

			$this->add_control(
				'link_address',
				[
					'label'   		=> esc_html__( 'Link', 'vedhak' ),
					'type'    		=> \Elementor\Controls_Manager::URL,
					'show_external' => false,
				]
			);
			
			$this->add_control(
				'html_tag',
				[
					'label' 	=> esc_html__( 'HTML Tag', 'vedhak' ),
					'type' 		=> \Elementor\Controls_Manager::SELECT,
					'default' 	=> 'h3',
					'options' 	=> [
						'h1' 		=> esc_html__( 'H1', 'vedhak' ),
						'h2'  		=> esc_html__( 'H2', 'vedhak' ),
						'h3'  		=> esc_html__( 'H3', 'vedhak' ),
						'h4' 		=> esc_html__( 'H4', 'vedhak' ),
						'h5' 		=> esc_html__( 'H5', 'vedhak' ),
						'h6' 		=> esc_html__( 'H6', 'vedhak' ),
						'div' 		=> esc_html__( 'Div', 'vedhak' ),
						'span' 		=> esc_html__( 'span', 'vedhak' ),
						'p' 		=> esc_html__( 'p', 'vedhak' ),
					],
				]
			);

			$this->add_responsive_control(
				'alignment',
				[
					'label' 	=> esc_html__( 'Alignment', 'vedhak' ),
					'type' 		=> \Elementor\Controls_Manager::CHOOSE,
					'options' 	=> [
						'left' => [
							'title' => esc_html__( 'Left', 'vedhak' ),
							'icon' 	=> 'eicon-text-align-left',
						],
						'center' => [
							'title' => esc_html__( 'Center', 'vedhak' ),
							'icon' 	=> 'eicon-text-align-center',
						],
						'right' => [
							'title' => esc_html__( 'Right', 'vedhak' ),
							'icon' 	=> 'eicon-text-align-right',
						],
					],
					'toggle' 	=> true,
					'selectors' => [
						'{{WRAPPER}} .ova-heading' => 'text-align: {{VALUE}}',
					],
					'condition' => [
						'template' => 'template1',
					],
				]
			);

			$this->add_control(
				'text_background',
				[
					'label' 	=> esc_html__( 'Text Background', 'vedhak' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> esc_html__( 'Camping', 'vedhak' ),
					'condition' => [
						'template' => 'template2',
					],
				]
			);

		$this->end_controls_section();

		$this->start_controls_section(
			'button_readmore_section',
			[
				'label' => esc_html__( 'Button Readmore', 'vedhak' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
				'condition' => [
					'template' => 'template2',
				],
			]
		);

			$this->add_control(
				'text_button_readmore',
				[
					'label' => esc_html__( 'Text', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::TEXT,
					'default' => esc_html__( 'Discover More', 'vedhak' ),
					'placeholder' => esc_html__( 'Type your title here', 'vedhak' ),
				]
			);

			$this->add_control(
				'link_button_readmore',
				[
					'label'   		=> esc_html__( 'Link', 'vedhak' ),
					'type'    		=> \Elementor\Controls_Manager::URL,
					'show_external' => false,
					'default' 		=> [
						'url' 			=> '#',
						'is_external' 	=> true,
						'nofollow' 		=> false,
					],
				]
			);

			$this->add_control(
				'icon_button_readmore',
				[
					'label' => esc_html__( 'Icon', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::ICONS,
					'default' => [
						'value' => 'fas fa-angle-double-right',
						'library' => 'fa-solid',
					],
				]
			);

		$this->end_controls_section();

		//SECTION TAB STYLE GENERAL
		$this->start_controls_section(
			'general_section',
			[
				'label' => esc_html__( 'General', 'vedhak' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_control(
				'general_background_color',
				[
					'label' => esc_html__( 'Background Color', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-heading ' => 'background-color: {{VALUE}}',
					],
				]
			);

			$this->add_responsive_control(
				'padding_general',
				[
					'label' 	 => esc_html__( 'Padding', 'vedhak' ),
					'type' 		 => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-heading , {{WRAPPER}} .ova-heading.template2 .wrap-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'margin_general',
				[
					'label' 	 => esc_html__( 'Margin', 'vedhak' ),
					'type' 		 => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-heading , {{WRAPPER}} .ova-heading.template2 .wrap-content' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();
		//END SECTION TAB STYLE GENERAL
		
		//SECTION TAB STYLE SUB TITLE
		$this->start_controls_section(
			'section_sub_title',
			[
				'label' => esc_html__( 'Sub Title', 'vedhak' ),
				'tab' 	=> Controls_Manager::TAB_STYLE,
				'condition' => [
					'template' => 'template1',
				],
			]
		);

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' 		=> 'content_typography_sub_title',
					'selector' 	=> '{{WRAPPER}} .ova-heading .sub-title',
				]
			);

			$this->add_control(
				'color_sub_title',
				[
					'label'	 	=> esc_html__( 'Color', 'vedhak' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-heading .sub-title' => 'color : {{VALUE}};'
					],
				]
			);

			$this->add_responsive_control(
				'margin_sub_title',
				[
					'label' 	 => esc_html__( 'Margin', 'vedhak' ),
					'type' 		 => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-heading .sub-title ' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'line_decoration',
				[
					'label' => esc_html__( 'Line Decoration', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

			$this->add_responsive_control(
				'line_decoration_width',
				[
					'label' => esc_html__( 'Width', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 500,
							'step' => 1,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-heading .sub-title .line-decoration' => 'width: {{SIZE}}{{UNIT}};',
					],
				]
			);
			
			$this->add_responsive_control(
				'line_decoration_height',
				[
					'label' => esc_html__( 'Height', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 30,
							'step' => 1,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-heading .sub-title .line-decoration' => 'height: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'color_line_decoration',
				[
					'label'	 	=> esc_html__( 'Color', 'vedhak' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-heading .sub-title .line-decoration' => 'background-color : {{VALUE}};'
					],
				]
			);

			$this->add_responsive_control(
				'margin_line_decoration',
				[
					'label' 	 => esc_html__( 'Margin', 'vedhak' ),
					'type' 		 => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-heading .sub-title .line-decoration' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);
			
		$this->end_controls_section();
		//END SECTION TAB STYLE SUB TITLE
		
		//SECTION TAB STYLE TITLE
		$this->start_controls_section(
			'section_title_style',
			[
				'label' => esc_html__( 'Title', 'vedhak' ),
				'tab' 	=> Controls_Manager::TAB_STYLE,
			]
		);
			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' 		=> 'content_typography_title',
					'label' 	=> esc_html__( 'Typography', 'vedhak' ),
					'selector' 	=> '{{WRAPPER}} .ova-heading .title',
				]
			);

			$this->add_responsive_control(
				'title_font_weight_text_bold',
				[
					'label' => esc_html__( 'Font Weight Text Bold', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px' ],
					'range' => [
						'px' => [
							'min' => 100,
							'max' => 900,
							'step' => 50,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-heading .title .title-bold' => 'font-weight: {{SIZE}};',
					],
				]
			);

			$this->add_responsive_control(
				'title_font_weight_text_normal',
				[
					'label' => esc_html__( 'Font Weight Text Normal', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px' ],
					'range' => [
						'px' => [
							'min' => 100,
							'max' => 900,
							'step' => 50,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-heading .title .title-normal' => 'font-weight: {{SIZE}};',
					],
				]
			);

			$this->add_control(
				'color_title',
				[
					'label' 	=> esc_html__( 'Color', 'vedhak' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-heading .title, {{WRAPPER}} .ova-heading .title a' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'color_title_hover',
				[
					'label' 	=> esc_html__( 'Color Hover', 'vedhak' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-heading .title:hover, {{WRAPPER}} .ova-heading .title:hover a, {{WRAPPER}} .ova-heading .top-heading .title:hover' => 'color : {{VALUE}};'
					],
					'condition' => [
						'link_address[url]!' => '',
					],
				]
			);

			$this->add_responsive_control( 
				'margin_title',
				[
					'label' 	 => esc_html__( 'Margin', 'vedhak' ),
					'type' 		 => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-heading .title ' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();
		//END SECTION TAB STYLE TITLE

		//SECTION TAB STYLE DESCRIPTION
		$this->start_controls_section(
			'section_description',
			[
				'label' => esc_html__( 'Description', 'vedhak' ),
				'tab' 	=> Controls_Manager::TAB_STYLE,
				'condition' => [
					'template' => 'template1',
				],
			]
		);

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' 		=> 'content_typography_description',
					'label' 	=> esc_html__( 'Typography', 'vedhak' ),
					'selector' 	=> '{{WRAPPER}} .ova-heading .description',
				]
			);

			$this->add_control(
				'color_description',
				[
					'label'	 	=> esc_html__( 'Color', 'vedhak' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-heading .description' => 'color : {{VALUE}};'		
					],
				]
			);

			$this->add_responsive_control(
				'margin_description',
				[
					'label' 	 => esc_html__( 'Margin', 'vedhak' ),
					'type' 		 => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-heading .description ' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);
			
		$this->end_controls_section();
		//END SECTION TAB STYLE DESCRIPTION

		//SECTION TAB STYLE BUTTON READMORE
		$this->start_controls_section(
			'button_readmore_section_style',
			[
				'label' => esc_html__( 'Button Readmore', 'vedhak' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
				'condition' => [
					'template' => 'template2',
				],
			]
		);

			$this->add_control(
				'button_readmore_background_color',
				[
					'label' => esc_html__( 'Background Color', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-heading .button-readmore ' => 'background-color: {{VALUE}}',
					],
				]
			);

			$this->add_control(
				'button_readmore_background_color_hover',
				[
					'label' => esc_html__( 'Background Color Hover', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-heading .button-readmore:hover ' => 'background-color: {{VALUE}}',
					],
				]
			);

			$this->add_responsive_control(
				'button_readmore_padding',
				[
					'label' 	 => esc_html__( 'Padding', 'vedhak' ),
					'type' 		 => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-heading .button-readmore' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'button_readmore_margin',
				[
					'label' 	 => esc_html__( 'Margin', 'vedhak' ),
					'type' 		 => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-heading .button-readmore' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'button_readmore_border_radius',
				[
					'label' 	 => esc_html__( 'Border Radius', 'vedhak' ),
					'type' 		 => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-heading .button-readmore' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'button_readmore_heading',
				[
					'label' => esc_html__( 'Text', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'button_readmore_typography',
					'selector' => '{{WRAPPER}} .ova-heading .button-readmore ',
				]
			);

			$this->add_control(
				'button_readmore_color',
				[
					'label' => esc_html__( 'Color', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-heading .button-readmore ' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_control(
				'button_readmore_color_hover',
				[
					'label' => esc_html__( 'Color Hover', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-heading .button-readmore:hover ' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_control(
				'button_readmore_icon_heading',
				[
					'label' => esc_html__( 'Icon', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

			$this->add_responsive_control(
				'icon_size',
				[
					'label' => esc_html__( 'Size', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 100,
							'step' => 1,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-heading .button-readmore  i' => 'font-size: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'icon_color',
				[
					'label' => esc_html__( 'Color', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-heading .button-readmore  i' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_control(
				'icon_color_hover',
				[
					'label' => esc_html__( 'Color Hover', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-heading .button-readmore:hover  i' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_responsive_control(
				'icon_margin',
				[
					'label' 	 => esc_html__( 'Margin', 'vedhak' ),
					'type' 		 => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-heading .button-readmore i' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();

		//SECTION TAB STYLE TITLE
		$this->start_controls_section(
			'section_text_background_style',
			[
				'label' => esc_html__( 'Text Background', 'vedhak' ),
				'tab' 	=> Controls_Manager::TAB_STYLE,
				'condition' => [
					'template' => 'template2',
				],
			]
		);

			$this->add_group_control(
				\Elementor\Group_Control_Text_Stroke::get_type(),
				[
					'name' => 'background_text_stroke',
					'selector' => '{{WRAPPER}} .ova-heading .background',
				]
			);

			$this->add_control(
				'text_background_position',
				[
					'label' => esc_html__( 'Position', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

			$this->add_responsive_control(
				'text_background_top',
				[
					'label' => esc_html__( 'Top', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 350,
							'step' => 1,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-heading .background' => 'top: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'text_background_right',
				[
					'label' => esc_html__( 'Right', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1500,
							'step' => 1,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-heading .background' => 'right: {{SIZE}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();
	}

	// Render Template Here
	protected function render() {
		$settings 					= 	$this->get_settings();

		$template 					= 	$settings['template'];

		$number_prefix  			= 	$settings['number_prefix'];
		$sub_title 					= 	$settings['sub_title'];
		$title_bold  				= 	$settings['title_bold'];
		$title_normal  				= 	$settings['title_normal'];
		$description  				= 	$settings['description'];

		$text_background  			= 	$settings['text_background'];

		$link      					= 	$settings['link_address'];
		$nofollow      				= 	( isset( $link['nofollow'] ) && $link['nofollow'] ) ? 'rel=nofollow' : '';
		$target           			=   ( isset( $link['is_external'] ) && $link['is_external'] == 'on' ) ? '_blank' : '_self';
		$html_tag  					= 	$settings['html_tag'];

		$text_button_readmore 		= 	$settings['text_button_readmore'];
		$icon_button_readmore  		= 	$settings['icon_button_readmore'];
		$link_button_readmore      	= 	$settings['link_button_readmore'];
		$nofollow_button_readmore   = 	( isset( $link_button_readmore ['nofollow'] ) && $link_button_readmore ['nofollow'] ) ? 'rel=nofollow' : '';
		$target_button_readmore   	=   ( isset( $link_button_readmore ['is_external'] ) && $link_button_readmore ['is_external'] == 'on' ) ? '_blank' : '_self';	

		?>

			<div class="ova-heading <?php echo esc_attr( $template ); ?>">

				<?php if( $template == 'template1' && ( !empty( $number_prefix ) || !empty( $sub_title ) ) ) : ?>

					<h2 class="sub-title">

						<?php echo esc_html( $number_prefix ); ?>

						<?php if( !empty( $number_prefix ) && !empty( $sub_title ) )  : ?>
							<span class="line-decoration"></span>
						<?php endif; ?>

						<?php echo esc_html( $sub_title ); ?>

					</h2>

				<?php endif; ?>

				<?php if($template == "template2") { ?>
					<div class="wrap-content">
				<?php } ?>

					<?php if( $link['url'] ) { ?>
					
						<<?php echo esc_attr( $html_tag ); ?> class="title"><a href="<?php echo esc_url( $link['url'] ); ?>" target="<?php echo esc_attr( $target ); ?>" <?php printf( $nofollow ); ?>><span class="title-bold"><?php printf( $title_bold ); ?></span><span class="title-normal"><?php printf( $title_normal ); ?></span></a></<?php echo esc_attr( $html_tag ); ?>>

					<?php } else { ?>

						<<?php echo esc_attr( $html_tag ); ?> class="title"><span class="title-bold"><?php printf( $title_bold );?></span><span class="title-normal"><?php printf( $title_normal );?></span></<?php echo esc_attr( $html_tag ); ?>>

					<?php } ?>


					<?php if( $template == 'template2' ) : ?>

						<?php if( $link_button_readmore['url'] ) { ?>
							<a href="<?php echo esc_attr( $link_button_readmore['url'] ); ?>" class="button-readmore " 
								target="<?php echo esc_attr( $target_button_readmore ); ?>" <?php printf( $nofollow_button_readmore ); ?>>

								<?php echo esc_html( $text_button_readmore ); ?>

								<?php \Elementor\Icons_Manager::render_icon( $icon_button_readmore, [ 'aria-hidden' => 'true' ] ); ?>
								
							</a>
						<?php } ?>

						<div class="background">
							<?php echo esc_html( $text_background ); ?>
						</div>

					<?php endif; ?>
				
				<?php if($template == "template2") { ?>
					</div>
				<?php } ?>

				<?php if( $template == 'template1' ) : ?>

					<?php if( $description ): ?>
						<p class="description"><?php echo esc_html( $description ); ?></p>
					<?php endif; ?>

				<?php endif; ?>

			</div>

		<?php
	}

	
}
$widgets_manager->register( new Vedhak_Elementor_Heading() );