<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class vedhak_Elementor_Icon_Box extends Widget_Base {

	public function get_name() {
		return 'vedhak_elementor_icon_box';
	}

	public function get_title() {
		return esc_html__( 'Ova Icon Box', 'vedhak' );
	}

	public function get_icon() {
		return 'eicon-icon-box';
	}

	public function get_categories() {
		return [ 'vedhak' ];
	}

	public function get_script_depends() {
		return [ '' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'vedhak' ),
			]
		);	
			
			// Add Class control
			$this->add_control(
				'template',
				[
					'label' => esc_html__( 'Template', 'vedhak' ),
					'type' => Controls_Manager::SELECT,
					'default' => 'template1',
					'options' => [
						'template1' => esc_html__('Template 1', 'vedhak'),
						'template2' => esc_html__('Template 2', 'vedhak'),
						'template3' => esc_html__('Template 3', 'vedhak'),
						'template4' => esc_html__('Template 4', 'vedhak'),
					]
				]
			);

			$this->add_control(
				'icon',
				[
					'label' => esc_html__( 'Icon', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::ICONS,
					'default' => [
						'value' => 'flaticon flaticon-014-tent-4',
						'library' => 'flaticon',
					],
				]
			);

			$this->add_control(
				'title',
				[
					'label' => esc_html__( 'Title', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::TEXT,
					'default' => esc_html__( 'Facilities/Prices', 'vedhak' ),
					'placeholder' => esc_html__( 'Type your title here', 'vedhak' ),
				]
			);

			$this->add_control(
				'link',
				[
					'label' => esc_html__( 'Link', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::URL,
					'placeholder' => esc_html__( 'https://your-link.com', 'vedhak' ),
					'options' => [ 'url', 'is_external', 'nofollow' ],
					'default' => [
						'url' => '#',
						'is_external' => false,
						'nofollow' => false,
					],
					'dynamic' => [
						'active' => true
					],
					'label_block' => true,
				]
			);

			$this->add_control(
				'description',
				[
					'label' => esc_html__( 'Description', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::TEXTAREA,
					'rows' => 10,
					'default' => esc_html__( 'Undertakes laborious physical exercise except to obtain some advantage has any right', 'vedhak' ),
					'placeholder' => esc_html__( 'Type your description here', 'vedhak' ),
				]
			);

			$this->add_control(
				'text_button',
				[
					'label' => esc_html__( 'Text Button', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::TEXT,
					'default' => esc_html__( 'Learn More', 'vedhak' ),
					'condition' => [
						'template!' => ['template1','template4'],
					],
				],
				
			);

			$this->add_control(
				'icon_button',
				[
					'label' => esc_html__( 'Icon', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::ICONS,
					'default' => [
						'value' => 'fas fa-angle-double-right',
						'library' => 'fa-solid',
					],
					'condition' => [
						'template!' => ['template1','template4'],
					],
				]
			);

	$this->end_controls_section();

	$this->start_controls_section(
		'general_style',
		[
			'label' => esc_html__( 'General', 'vedhak' ),
			'tab' => \Elementor\Controls_Manager::TAB_STYLE,
		]
	);

		$this->add_control(
			'background_color',
			[
				'label' => esc_html__( 'Background Color', 'vedhak' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-icon-box .iconbox ' => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .ova-icon-box.template2 .iconbox:after ' => 'background-color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'background_color_hover',
			[
				'label' => esc_html__( 'Background Color Hover', 'vedhak' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-icon-box:hover .iconbox ' => 'background-color: {{VALUE}}',
				],
				'condition' => [
					'template!' => 'template2',
				],
			]
		);

		$this->add_responsive_control(
			'general_padding',
			[
				'label' => esc_html__( 'Padding', 'vedhak' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em', 'rem' ],
				'selectors' => [
					'{{WRAPPER}} .ova-icon-box .iconbox ' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'general_margin',
			[
				'label' => esc_html__( 'Margin', 'vedhak' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em', 'rem' ],
				'selectors' => [
					'{{WRAPPER}} .ova-icon-box .iconbox ' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			[
				'name' => 'general_border',
				'selector' => '{{WRAPPER}} .ova-icon-box .iconbox',
			]
		);

		$this->add_control(
			'general_border_radius',
			[
				'label' => esc_html__( 'Border Radius', 'vedhak' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em', 'rem' ],
				'selectors' => [
					'{{WRAPPER}} .ova-icon-box .iconbox ' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'general_box_shadow',
				'selector' => '{{WRAPPER}} .ova-icon-box .iconbox',
			]
		);

		$this->add_control(
			'general_alignment',
			[
				'label' => esc_html__( 'Alignment', 'vedhak' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'flex-start' => [
						'title' => esc_html__( 'Top', 'vedhak' ),
						'icon' => ' eicon-v-align-top',
					],
					'center' => [
						'title' => esc_html__( 'Middle', 'vedhak' ),
						'icon' => 'eicon-v-align-middle',
					],
					'flex-end' => [
						'title' => esc_html__( 'Bottom', 'vedhak' ),
						'icon' => 'eicon-v-align-bottom',
					],
				],
				'default' => 'flex-start',
				'toggle' => true,
				'selectors' => [
					'{{WRAPPER}} .ova-icon-box .iconbox' => 'align-items: {{VALUE}};',
				],
				'condition' => [
					'template' => 'template1',
				],
			]
		);

	$this->end_controls_section();

	$this->start_controls_section(
			'icon_section',
			[
				'label' => esc_html__( 'Icon', 'vedhak' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_responsive_control(
				'icon_size',
				[
					'label' => esc_html__( 'Size', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 200,
							'step' => 1,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-icon-box .iconbox .icon i' => 'font-size: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'icon_background_size',
				[
					'label' => esc_html__( 'Background Size', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 400,
							'step' => 1,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-icon-box .iconbox .icon' => 'width: {{SIZE}}{{UNIT}};min-width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
					],
					'condition' => [
						'template!' => 'template4',
					],
				]
			);

			$this->add_control(
				'background_border_radius',
				[
					'label' => esc_html__( 'Background Border Radius', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'selectors' => [
						'{{WRAPPER}} .ova-icon-box .iconbox .icon' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
					'condition' => [
						'template!' => 'template4',
					],
				]
			);

			$this->add_responsive_control(
				'icon_margin',
				[
					'label' => esc_html__( 'Margin', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'selectors' => [
						'{{WRAPPER}} .ova-icon-box .iconbox .icon' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->start_controls_tabs(
				'icon_tabs',
			);

				$this->start_controls_tab(
					'icon_normal_tab',
					[
						'label' => esc_html__( 'Normal', 'vedhak' ),
					]
				);

					$this->add_control(
						'icon_color',
						[
							'label' => esc_html__( 'Icon Color', 'vedhak' ),
							'type' => \Elementor\Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-icon-box .iconbox .icon i' => 'color: {{VALUE}}',
							],
						]
					);

					$this->add_control(
						'icon_background_color',
						[
							'label' => esc_html__( 'Background Color', 'vedhak' ),
							'type' => \Elementor\Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-icon-box .iconbox .icon' => 'background-color: {{VALUE}}',
							],
							'condition' => [
								'template!' => 'template4',
							],
						]
					);

					$this->add_group_control(
						\Elementor\Group_Control_Border::get_type(),
						[
							'name' => 'background_border',
							'selector' => '{{WRAPPER}} .ova-icon-box .iconbox .icon',
							'condition' => [
								'template' => 'template3',
							],
						]
					);

				$this->end_controls_tab();

				$this->start_controls_tab(
					'icon_hover_tab',
					[
						'label' => esc_html__( 'Hover', 'vedhak' ),
					]
				);

					$this->add_control(
						'icon_hover_color',
						[
							'label' => esc_html__( 'Icon Color', 'vedhak' ),
							'type' => \Elementor\Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-icon-box:hover .iconbox .icon i' => 'color: {{VALUE}}',
							],
						]
					);

					$this->add_control(
						'icon_background_hover_color',
						[
							'label' => esc_html__( 'Background Color', 'vedhak' ),
							'type' => \Elementor\Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-icon-box:hover .iconbox .icon' => 'background-color: {{VALUE}}',
							],
							'condition' => [
								'template!' => 'template4',
							],
						]
					);

					$this->add_group_control(
						\Elementor\Group_Control_Border::get_type(),
						[
							'name' => 'background_border_hover',
							'selector' => '{{WRAPPER}} .ova-icon-box:hover .iconbox .icon',
							'condition' => [
								'template' => 'template3',
							],
						]
					);

				$this->end_controls_tab();

			$this->end_controls_tabs();

	$this->end_controls_section();

	$this->start_controls_section(
		'content_title',
		[
			'label' => esc_html__( 'Title', 'vedhak' ),
			'tab' => \Elementor\Controls_Manager::TAB_STYLE,
		]
	);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'selector' => '{{WRAPPER}} .ova-icon-box .iconbox  .content .title',
			]
		);


		$this->add_control(
			'title_color',
			[
				'label' => esc_html__( 'Color', 'vedhak' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-icon-box .iconbox .content .title' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'title_hover_color',
			[
				'label' => esc_html__( 'Color Hover', 'vedhak' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-icon-box:hover .iconbox .content .title' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_responsive_control(
			'title_margin',
			[
				'label' => esc_html__( 'Margin', 'vedhak' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em', 'rem' ],
				'selectors' => [
					'{{WRAPPER}} .ova-icon-box .iconbox  .content .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
	
	$this->end_controls_section();

	$this->start_controls_section(
		'content_description',
		[
			'label' => esc_html__( 'Description', 'vedhak' ),
			'tab' => \Elementor\Controls_Manager::TAB_STYLE,
		]
	);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'description_typography',
				'selector' => '{{WRAPPER}} .ova-icon-box .iconbox  .content .description',
			]
		);

		$this->add_control(
			'description_color',
			[
				'label' => esc_html__( 'Color', 'vedhak' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-icon-box .iconbox .content .description' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'description_hover_color',
			[
				'label' => esc_html__( 'Color Hover', 'vedhak' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-icon-box:hover .iconbox .content  .description' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_responsive_control(
			'description_margin',
			[
				'label' => esc_html__( 'Margin', 'vedhak' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em', 'rem' ],
				'selectors' => [
					'{{WRAPPER}} .ova-icon-box .iconbox  .content .description' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);	

	$this->end_controls_section();

	$this->start_controls_section(
		'line_decoration',
		[
			'label' => esc_html__( 'Line Decoration', 'vedhak' ),
			'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			'condition' => [
				'template!' => 'template1',
			],
		]
	);

		$this->add_control(
			'line_decoration_width',
			[
				'label' => esc_html__( 'Width', 'vedhak' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'em', 'rem' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 1,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .ova-icon-box .iconbox .line-decoration' => 'width: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'line_decoration_height',
			[
				'label' => esc_html__( 'Height', 'vedhak' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'em', 'rem' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 20,
						'step' => 1,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .ova-icon-box .iconbox .line-decoration' => 'height: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'line_decoration_color',
			[
				'label' => esc_html__( 'Color', 'vedhak' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-icon-box .iconbox .line-decoration' => 'background-color: {{VALUE}}',
				],
			]
		);

		$this->add_responsive_control(
			'line_decoration_margin',
			[
				'label' => esc_html__( 'Margin', 'vedhak' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em', 'rem' ],
				'selectors' => [
					'{{WRAPPER}} .ova-icon-box .iconbox .line-decoration' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

	$this->end_controls_section();

	$this->start_controls_section(
		'button_readmore_section',
			[
				'label' => esc_html__( ' Button Readmore', 'vedhak' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
				'condition' => [
					'template!' => ['template1','template4'],
				],
			]
		);

			$this->add_responsive_control(
				'button_readmore_margin',
				[
					'label' => esc_html__( 'Margin', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'selectors' => [
						'{{WRAPPER}} .ova-icon-box .iconbox  .button-readmore' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'text_button_heading',
				[
					'label' => esc_html__( 'Text', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'text_button_typography',
					'selector' => '{{WRAPPER}} .ova-icon-box .iconbox  .button-readmore .text-button',
				]
			);

			$this->add_control(
				'text_button_color',
				[
					'label' => esc_html__( 'Color', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-icon-box .iconbox  .button-readmore .text-button' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_control(
				'text_button_color_hover',
				[
					'label' => esc_html__( 'Color Hover', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-icon-box:hover .iconbox  .button-readmore .text-button' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_responsive_control(
				'text_button_margin',
				[
					'label' => esc_html__( 'Margin', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'selectors' => [
						'{{WRAPPER}} .ova-icon-box .iconbox  .button-readmore .text-button' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'icon_button_heading',
				[
					'label' => esc_html__( 'Icon', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

			$this->add_responsive_control(
				'icon_button_size',
				[
					'label' => esc_html__( 'Size', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 200,
							'step' => 1,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-icon-box .button-readmore .icon-button i' => 'font-size: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'icon_button_color',
				[
					'label' => esc_html__( 'Color', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-icon-box .iconbox  .button-readmore .icon-button i' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_control(
				'icon_button_color_hover',
				[
					'label' => esc_html__( 'Color Hover', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-icon-box:hover .iconbox  .button-readmore .icon-button i' => 'color: {{VALUE}}',
					],
				]
			);

	$this->end_controls_section();
	}

	// Render Template Here
	protected function render() {
		$settings = $this->get_settings();

		$icon 					= $settings['icon'];
		$templates 				= $settings['template'];
		$title 					= $settings['title'];
		$description 			= $settings['description'];
		$link 					= $settings['link'];
		$text_button 			= $settings['text_button'];
		$icon_button         	= $settings['icon_button'];

		?>

		<div class="ova-icon-box <?php echo esc_attr($templates);?>"> 

			<?php if ( !empty( $link['url'] ) ) {
				$this->add_link_attributes( 'link', $link );
			?>
				<a class="iconbox" <?php $this->print_render_attribute_string( 'link' ); ?> >
			<?php } else { ?>	
				<div class="iconbox">
			<?php } ?>	

				<span class="icon">
					<?php \Elementor\Icons_Manager::render_icon( $icon, [ 'aria-hidden' => 'true' ] ); ?>
				</span>
				
				<div class="content">

					<?php if( $title ) {  ?>
						<h3 class="title">
							<?php echo esc_html($title) ;?>
						</h3>
	                <?php } ?>

	                <?php if ($description) { ?>
						<p class="description">
							<?php echo esc_html($description) ;?>
						</p>
					<?php  } ?>

				</div>
				
				<?php if( $templates != 'template1' ) {  ?>
					<div class="line-decoration"></div>
				<?php } ?>

				<?php if( $templates != 'template1' && $templates != 'template4') {  ?>	

					<div class="button-readmore">
						<span class="text-button"><?php echo esc_html($text_button); ?></span>
						<span class="icon-button"><?php \Elementor\Icons_Manager::render_icon( $icon_button , [ 'aria-hidden' => 'true' ] ); ?></span> 
					</div> 
			
				<?php } ?>


			<?php if ( !empty( $link['url'] ) ) { ?>
				</a> 
			<?php } else { ?>	
				</div>
			<?php } ?>	

		</div>

		<?php
	}

	
}
$widgets_manager->register( new vedhak_Elementor_Icon_Box() );