<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Vedhak_Elementor_Icon_List extends Widget_Base {

	public function get_name() {
		return 'vedhak_elementor_icon_list';
	}

	public function get_title() {
		return esc_html__( 'Ova Icon List', 'vedhak' );
	}

	public function get_icon() {
		return ' eicon-editor-list-ul';
	}

	public function get_categories() {
		return [ 'vedhak' ];
	}

	public function get_script_depends() {
		return [ '' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'vedhak' ),
			]
		);	

			$this->add_control(
				'number_column',
				[
					'label' => esc_html__( 'Number Column', 'vedhak' ),
					'type' => Controls_Manager::SELECT,
					'default' => 'three_column',
					'options' => [
						'one_column' => esc_html__('Single Column', 'vedhak'),
						'two_column' => esc_html__('2 Columns', 'vedhak'),
						'three_column' => esc_html__('3 Columns', 'vedhak'),
					]
				]
			);
			
			$repeater = new \Elementor\Repeater();

			$repeater->add_control(
				'icon',
				[
					'label' => esc_html__( 'Icon', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::ICONS,
					'default' => [
						'value' => 'flaticon flaticon-014-tent-4',
						'library' => 'flaticon',
					],
				]
			);

			$repeater->add_control(
				'title',
				[
					'label' => esc_html__( 'Title', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::TEXT,
					'default' => esc_html__( 'Private Cottages', 'vedhak' ),
					'placeholder' => esc_html__( 'Type your title here', 'vedhak' ),
				]
			);

			$repeater->add_control(
				'link',
				[
					'label' => esc_html__( 'Link', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::URL,
					'placeholder' => esc_html__( 'https://your-link.com', 'vedhak' ),
					'options' => [ 'url', 'is_external', 'nofollow' ],
					'default' => [
						'url' => '#',
						'is_external' => true,
						'nofollow' => false,
					],
					'dynamic' => [
						'active' => true
					],
					'label_block' => true,
				]
			);

			$repeater->add_control(
				'description',
				[
					'label' => esc_html__( 'Description', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::TEXTAREA,
					'rows' => 10,
					'default' => esc_html__( 'Sit amet consectetur adipiscing elitcelerisque aenectus bibendum facilisi tempus', 'vedhak' ),
					'placeholder' => esc_html__( 'Type your description here', 'vedhak' ),
				]
			);

			$repeater->add_control(
				'text_button',
				[
					'label' => esc_html__( 'Text Button', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::TEXT,
					'default' => esc_html__( 'Read More', 'vedhak' ),
				],
			);

			$repeater->add_control(
				'icon_button',
				[
					'label' => esc_html__( 'Icon', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::ICONS,
					'default' => [
						'value' => 'fas fa-angle-double-right',
						'library' => 'fa-solid',
					],
				]
			);

			$this->add_control(
				'items',
				[
					'label' => esc_html__( 'List Content', 'vedhak' ),
					'type' => Controls_Manager::REPEATER,
					'fields' => $repeater->get_controls(),
					'default' => [
						[	
							'icon' => [
								'value'    => 'flaticon flaticon-021-cottage-1',
								'library'  => 'flaticon',
							],
							'title'      => esc_html__( 'Private Cottages', 'vedhak' ),
							 
						],
						[	
							'icon' => [
								'value'    => 'flaticon flaticon-022-tent-6',
								'library'  => 'flaticon',
							],
							'title'      => esc_html__( 'Tents on Rent', 'vedhak' ),
							 
						],
						[	
							'icon' => [
								'value'    => 'flaticon flaticon-023-hiking-1',
								'library'  => 'flaticon',
							],
							'title'      => esc_html__( 'Summer Camp', 'vedhak' ),
							 
						],
						[	
							'icon' => [
								'value'    => 'flaticon flaticon-024-campfire-1',
								'library'  => 'flaticon',
							],
							'title'      => esc_html__( 'Wood Fire', 'vedhak' ),
							 
						],
						[	
							'icon' => [
								'value'    => 'flaticon flaticon-025-eco-house',
								'library'  => 'flaticon',
							],
							'title'      => esc_html__( 'Electrical Cabinets', 'vedhak' ),
							 
						],
						[	
							'icon' => [
								'value'    => 'flaticon flaticon-026-washing-machine',
								'library'  => 'flaticon',
							],
							'title'      => esc_html__( 'Washing Machines', 'vedhak' ),
							 
						],
					],
					'title_field' => '{{{ title }}}',
				]
			);

		$this->end_controls_section();

		$this->start_controls_section(
		'general_style',
		[
			'label' => esc_html__( 'General', 'vedhak' ),
			'tab' => \Elementor\Controls_Manager::TAB_STYLE,
		]
	);

		$this->add_responsive_control(
			'general_space',
			[
				'label' => esc_html__( 'Space', 'vedhak' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'em', 'rem'],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 200,
						'step' => 1,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .ova-icon-list' => 'column-gap: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'background_color',
			[
				'label' => esc_html__( 'Background Color', 'vedhak' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-icon-list .item ' => 'background-color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'background_color_hover',
			[
				'label' => esc_html__( 'Background Color Hover', 'vedhak' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-icon-list .item:hover ' => 'background-color: {{VALUE}}',
				],
			]
		);

		$this->add_responsive_control(
			'general_padding',
			[
				'label' => esc_html__( 'Padding', 'vedhak' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em', 'rem' ],
				'selectors' => [
					'{{WRAPPER}} .ova-icon-list .item ' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'general_margin',
			[
				'label' => esc_html__( 'Margin', 'vedhak' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em', 'rem' ],
				'selectors' => [
					'{{WRAPPER}} .ova-icon-list .item ' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			[
				'name' => 'general_border',
				'selector' => '{{WRAPPER}} .ova-icon-list .item',
			]
		);

		$this->add_control(
			'general_border_radius',
			[
				'label' => esc_html__( 'Border Radius', 'vedhak' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em', 'rem' ],
				'selectors' => [
					'{{WRAPPER}} .ova-icon-list .item ' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'general_box_shadow',
				'selector' => '{{WRAPPER}} .ova-icon-list .item:hover',
				'label' => esc_html__( ' Hover Box Shadow', 'vedhak' ),
				'label_block' => true,
				'condition' => [
					'template' => 'template1',
				],
			]
		);

	$this->end_controls_section();

	$this->start_controls_section(
		'icon_section',
		[
			'label' => esc_html__( 'Icon', 'vedhak' ),
			'tab' => \Elementor\Controls_Manager::TAB_STYLE,
		]
	);

		$this->add_responsive_control(
			'icon_size',
			[
				'label' => esc_html__( 'Size', 'vedhak' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'em', 'rem' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 150,
						'step' => 1,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .ova-icon-list .item .icon i' => 'font-size: {{SIZE}}{{UNIT}};',
				],
			]
		);
		$this->add_control(
			'icon_color',
			[
				'label' => esc_html__( 'Icon Color', 'vedhak' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-icon-list .item .icon i' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'icon_hover_color',
			[
				'label' => esc_html__( 'Icon Color', 'vedhak' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-icon-list .item:hover .icon i' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_responsive_control(
			'icon_margin',
			[
				'label' => esc_html__( 'Margin', 'vedhak' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em', 'rem' ],
				'selectors' => [
					'{{WRAPPER}} .ova-icon-list .item .icon' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

	$this->end_controls_section();

	$this->start_controls_section(
		'content_title',
		[
			'label' => esc_html__( 'Title', 'vedhak' ),
			'tab' => \Elementor\Controls_Manager::TAB_STYLE,
		]
	);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'selector' => '{{WRAPPER}} .ova-icon-list .item .title',
			]
		);

		$this->add_control(
			'title_color',
			[
				'label' => esc_html__( 'Color', 'vedhak' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-icon-list .item .title' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'title_hover_color',
			[
				'label' => esc_html__( 'Color Hover', 'vedhak' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-icon-list .item:hover .title' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_responsive_control(
			'title_margin',
			[
				'label' => esc_html__( 'Margin', 'vedhak' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em', 'rem' ],
				'selectors' => [
					'{{WRAPPER}} .ova-icon-list .item .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
	
	$this->end_controls_section();

	$this->start_controls_section(
		'line_decoration',
		[
			'label' => esc_html__( 'Line Decoration', 'vedhak' ),
			'tab' => \Elementor\Controls_Manager::TAB_STYLE,
		]
	);

		$this->add_responsive_control(
			'line_decoration_margin',
			[
				'label' => esc_html__( 'Margin', 'vedhak' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em', 'rem' ],
				'selectors' => [
					'{{WRAPPER}} .ova-icon-list .item .line-decoration' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'line_decoration_width',
			[
				'label' => esc_html__( 'Width', 'vedhak' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'em', 'rem' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 300,
						'step' => 1,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .ova-icon-list .item .line-decoration:after' => 'width: {{SIZE}}{{UNIT}};',
				],
				'separator' => 'before',
			]
		);

		$this->add_responsive_control(
			'line_decoration_weight',
			[
				'label' => esc_html__( 'Weight', 'vedhak' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'em', 'rem' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 20,
						'step' => 1,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .ova-icon-list .item .line-decoration:after' => 'height: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'line_decoration_color',
			[
				'label' => esc_html__( 'Color', 'vedhak' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-icon-list .item .line-decoration:after' => 'background-color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'line_decoration_color_hover',
			[
				'label' => esc_html__( 'Color Hover', 'vedhak' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-icon-list .item:hover .line-decoration:after' => 'background-color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'line_decoration_background',
			[
				'label' => esc_html__( 'Background', 'vedhak' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_responsive_control(
			'line_decoration_background_weight',
			[
				'label' => esc_html__( 'Weight', 'vedhak' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'em', 'rem' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 20,
						'step' => 1,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .ova-icon-list .item .line-decoration' => 'height: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'line_decoration_background_color',
			[
				'label' => esc_html__( 'Color', 'vedhak' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-icon-list .item .line-decoration' => 'background-color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'line_decoration_background_color_hover',
			[
				'label' => esc_html__( 'Color Hover', 'vedhak' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-icon-list .item:hover .line-decoration' => 'background-color: {{VALUE}}',
				],
			]
		);

	$this->end_controls_section();

	$this->start_controls_section(
		'content_description',
		[
			'label' => esc_html__( 'Description', 'vedhak' ),
			'tab' => \Elementor\Controls_Manager::TAB_STYLE,
		]
	);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'description_typography',
				'selector' => '{{WRAPPER}} .ova-icon-list .item .description',
			]
		);

		$this->add_control(
			'description_color',
			[
				'label' => esc_html__( 'Color', 'vedhak' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ova-icon-list .item .description' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_responsive_control(
			'description_margin',
			[
				'label' => esc_html__( 'Margin', 'vedhak' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em', 'rem' ],
				'selectors' => [
					'{{WRAPPER}} .ova-icon-list .item .description' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);	

	$this->end_controls_section();

	$this->start_controls_section(
		'button_readmore_section',
			[
				'label' => esc_html__( ' Button Readmore', 'vedhak' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_responsive_control(
				'button_readmore_margin',
				[
					'label' => esc_html__( 'Margin', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'selectors' => [
						'{{WRAPPER}} .ova-icon-list .item  .button-readmore' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'text_button_heading',
				[
					'label' => esc_html__( 'Text', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'text_button_typography',
					'selector' => '{{WRAPPER}} .ova-icon-list .item  .button-readmore .text-button',
				]
			);

			$this->add_control(
				'text_button_color',
				[
					'label' => esc_html__( 'Color', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-icon-list .item  .button-readmore .text-button' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_control(
				'text_button_color_hover',
				[
					'label' => esc_html__( 'Color Hover', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-icon-list:hover .item  .button-readmore .text-button' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_responsive_control(
				'text_button_margin',
				[
					'label' => esc_html__( 'Margin', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'selectors' => [
						'{{WRAPPER}} .ova-icon-list .item  .button-readmore .text-button' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'icon_button_heading',
				[
					'label' => esc_html__( 'Icon', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

			$this->add_responsive_control(
				'icon_button_size',
				[
					'label' => esc_html__( 'Size', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 200,
							'step' => 1,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-icon-list .button-readmore .icon-button i' => 'font-size: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'icon_button_color',
				[
					'label' => esc_html__( 'Color', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-icon-list .item  .button-readmore .icon-button i' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_control(
				'icon_button_color_hover',
				[
					'label' => esc_html__( 'Color Hover', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-icon-list:hover .item  .button-readmore .icon-button i' => 'color: {{VALUE}}',
					],
				]
			);

	$this->end_controls_section();
	}

	// Render Template Here
	protected function render() {
		$settings = $this->get_settings();

        $number_column      =    $settings['number_column'];
		$items            	=    $settings['items'];

		?>

			<div class="ova-icon-list  <?php echo esc_attr($number_column) ;?>">
	            	
		         <?php 
		           foreach( $items as $item ) { 
		               $icon 				=    $item['icon']['value'];
		           	   $title      			=    $item['title'];
					   $link       			=    $item['link'];
					   $nofollow  			=    ( isset( $link['nofollow'] ) && $link['nofollow'] ) ? ' rel="nofollow"' : '';
		               $target     			=    ( isset( $link['is_external'] ) && $link['is_external'] == 'on' ) ? '_blank' : '_self'; 
		               $description       	=    $item['description'];
		               $text_button       	=    $item['text_button'];
		               $icon_button       	=    $item['icon_button']['value'];
				  
			    ?>

			    <?php if ( $link['url'] != '' ) { ?>

					<a class="item" href="<?php echo esc_url( $link['url'] ); ?>" target="<?php echo esc_html( $target ); ?>" <?php echo esc_attr( $nofollow ); ?> title="<?php echo esc_attr( $title ); ?>">

				<?php }else{ ?>

					<div class="item">

				<?php } ?>

					<div class="icon-title">
						
						<?php if ( !empty ( $icon )) : ?>

							<div class="icon">
								<i class="<?php echo esc_attr( $icon ); ?>"></i>
							</div>

						<?php endif; ?>

						<?php if ( !empty ($title)) : ?>

							<h3 class="title">
								<?php echo esc_html( $title ); ?>
							</h3>

						<?php endif; ?>

					</div>


					<div class="line-decoration"></div>


					<?php if ($description) { ?>

						<p class="description">
							<?php echo esc_html( $description ) ;?>
						</p>

					<?php  } ?>

					<?php if( !empty($text_button) || !empty($icon_button) ) : ?>

						<div class="button-readmore">

							<span class="text-button"><?php echo esc_html( $text_button ); ?></span>

							<span class="icon-button">
								<i class="<?php echo esc_attr( $icon_button ); ?>"></i>
							</span> 

						</div> 

					<?php endif; ?>


				<?php if ( $link['url'] != '' ) { ?>
					</a>
				<?php }else{ ?>
					</div>
				<?php } ?>
				

				<?php } ?>

			</div>

		<?php
	}
}
$widgets_manager->register( new Vedhak_Elementor_Icon_List() );