<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Vedhak_Elementor_Image_Box extends Widget_Base {

	public function get_name() {
		return 'vedhak_elementor_image_box';
	}

	public function get_title() {
		return esc_html__( 'Ova Image Box', 'vedhak' );
	}

	public function get_icon() {
		return 'eicon-featured-image';
	}

	public function get_categories() {
		return [ 'vedhak' ];
	}

	public function get_script_depends() {
		return [ '' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'vedhak' ),
			]
		);	
			
			// Add Class control

			$this->add_control(
				'link',
				[
					'label' => esc_html__( 'Link', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::URL,
					'placeholder' => esc_html__( 'https://your-link.com', 'vedhak' ),
					'options' => [ 'url', 'is_external', 'nofollow' ],
					'dynamic' => [
						'active' => true,
					],
				]
			);

			$this->add_control(
				'image',
				[
					'label' => esc_html__( 'Image', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::MEDIA,
					'default' => [
						'url' => \Elementor\Utils::get_placeholder_image_src(),
					],
				]
			);

			$this->add_control(
				'title',
				[
					'label' => esc_html__( 'Title', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::TEXTAREA,
					'default' => esc_html__( 'Luxury Cauple Cabin', 'vedhak' ),
					'placeholder' => esc_html__( 'Type your title here', 'vedhak' ),
				]
			);

			$this->add_control(
				'tag',
				[
					'label' => esc_html__( 'HTML Tag', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'default' => 'h3',
					'options' => [
						'h1' => esc_html__( 'H1', 'vedhak' ),
						'h2' => esc_html__( 'H2', 'vedhak' ),
						'h3' => esc_html__( 'H3', 'vedhak' ),
						'h4' => esc_html__( 'H4', 'vedhak' ),
						'h5' => esc_html__( 'H5', 'vedhak' ),
						'h6' => esc_html__( 'H6', 'vedhak' ),
						'div' => esc_html__( 'div', 'vedhak' ),
						'span' => esc_html__( 'span', 'vedhak' ),
						'p' => esc_html__( 'p', 'vedhak' ),
					],
				]
			);

			$this->add_control(
				'price',
				[
					'label' => esc_html__( 'Price', 'vedhak' ),
					'type' => Controls_Manager::TEXT,
					'default' => esc_html__( '$193', 'vedhak' ),
				]
			);

		$this->end_controls_section();

		$this->start_controls_section(
			'image_section',
			[
				'label' => esc_html__( 'Image', 'vedhak' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		   $this->add_responsive_control(
				'image_height',
				[
					'label' => esc_html__( 'Height', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'range' => [
						'px' => [
							'min' => 200,
							'max' => 600,
							'step' => 1,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-image-box .img' => 'height: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'image_overlay_color',
				[
					'label' => esc_html__( 'Overlay Color', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-image-box:before' => 'background-color: {{VALUE}}',
					],
				]
			);

		$this->end_controls_section();

		$this->start_controls_section(
			'title_section',
			[
				'label' => esc_html__( 'Title', 'vedhak' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'title_typography',
					'selector' => '{{WRAPPER}} .ova-image-box .title',
				]
			);

			$this->add_control(
				'title_color',
				[
					'label' => esc_html__( 'Color', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-image-box .title' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_control(
				'line_color',
				[
					'label' => esc_html__( 'Line Color', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-image-box .title:before' => 'background-color: {{VALUE}}',
					],
				]
			);

			$this->add_responsive_control(
				'line_width',
				[
					'label' => esc_html__( 'Line Width', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 150,
							'step' => 1,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-image-box .title:before' => 'width: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'title_margin',
				[
					'label' => esc_html__( 'Margin', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'selectors' => [
						'{{WRAPPER}} .ova-image-box .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();

		$this->start_controls_section(
			'price_section',
			[
				'label' => esc_html__( 'Price', 'vedhak' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'price_typography',
					'selector' => '{{WRAPPER}} .ova-image-box .price',
				]
			);

			$this->add_control(
				'price_color',
				[
					'label' => esc_html__( 'Color', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-image-box .price' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_control(
				'price_background_color',
				[
					'label' => esc_html__( 'Background Color', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-image-box .price' => 'background-color: {{VALUE}}',
					],
				]
			);

			$this->add_responsive_control(
				'price_background_size',
				[
					'label' => esc_html__( 'Background Size', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'range' => [
						'px' => [
							'min' => 65,
							'max' => 160,
							'step' => 1,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-image-box .price' => 'width: {{SIZE}}{{UNIT}};min-width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();
	}

	// Render Template Here
	protected function render() {

		$settings = $this->get_settings();

		$title 		 = 	$settings['title'];
		$tag 		 = 	$settings['tag'];
		$price       =  $settings['price'];

		$image 		 = 	$settings['image'];
		$url		 = 	$settings['image']['url'];
		$image_alt 	 =  ( isset( $settings['image']['alt']) &&  $settings['image']['alt'] != '' ) ?  $settings['image']['alt'] : $title;

		$link        =  $settings['link'];
		$nofollow    =  ( isset( $link['nofollow'] ) && $link['nofollow'] == 'on' ) ? 'nofollow' : '';
		$target      =  ( isset( $link['is_external'] ) && $link['is_external'] == 'on' ) ? '_blank' : '_self';

		?>

		<?php if( !empty($link['url'])) : ?>
			<a href="<?php echo esc_url($link['url']); ?>" target="<?php echo esc_attr($target); ?>" rel="<?php echo esc_attr($nofollow);?>">
		<?php endif; ?>

			<div class="ova-image-box">

				<div class="title-price">

					<?php if( !empty( $title ) ) { ?>
						<<?php echo esc_html( $tag ); ?> class="title"><?php echo esc_html( $title ); ?></<?php echo esc_html( $tag ); ?>>
					<?php } ?>

					<?php if( !empty( $price ) ) :?>
		                <div class="price"><?php echo esc_html( $price ) ;?></div>
		            <?php endif; ?>

				</div>

				<?php if( !empty( $url ) ) : ?>
					<img class="img" src="<?php echo esc_attr( $url ); ?>" alt="<?php echo esc_attr( $image_alt ); ?>">
				<?php endif; ?>	 

			</div>

			<?php if( !empty($link['url'])) : ?>
				</a>
			<?php endif; ?>

		<?php
	}
}

$widgets_manager->register( new Vedhak_Elementor_Image_Box() );