<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Vedhak_Elementor_Our_Team extends Widget_Base {

	public function get_name() {
		return 'vedhak_elementor_our_team';
	}

	public function get_title() {
		return esc_html__( 'Our Team', 'vedhak' );
	}

	public function get_icon() {
		return 'eicon-user-circle-o';
	}

	public function get_categories() {
		return [ 'vedhak' ];
	}

	public function get_script_depends() {
		return [ '' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'vedhak' ),
			]
		);	
			
			$this ->add_control(
				'image',
				[
					'label' => esc_html__( 'Choose Image', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::MEDIA,
					'default' => [
						'url' => \Elementor\Utils::get_placeholder_image_src(),
					],
				]
			);

			$this->add_control(
				'link',
				[
					'label' => esc_html__( 'Link', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::URL,
					'placeholder' => esc_html__( 'https://your-link.com', 'vedhak' ),
					'options' => [ 'url', 'is_external', 'nofollow' ],
					'default' => [
						'url' => '#',
						'is_external' => true,
						'nofollow' => false,
					],
				]
			);

			$this ->add_control(
				'name',
				[
					'label' => esc_html__( 'Name', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::TEXT,
					'default' => esc_html__( 'Michael F. Jimenez', 'vedhak' ),
					'placeholder' => esc_html__( 'Type your name here', 'vedhak' ),
				]
			);

			$this->add_control(
				'job',
				[
					'label' => esc_html__( 'Job', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::TEXT,
					'default' => esc_html__( 'CEO & Founder', 'vedhak' ),
					'placeholder' => esc_html__( 'Type your job here', 'vedhak' ),
				]
			);

			$repeater = new \Elementor\Repeater();

			$repeater->add_control(
				'icon_title',
				[
					'label' => esc_html__( 'Title', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::TEXT,
					'default' => esc_html__( 'Title', 'vedhak' ),
					'placeholder' => esc_html__( 'Type your title here', 'vedhak' ),
				]
			);

			$repeater->add_control(
				'social_icon',
				[
					'label' => esc_html__( 'Icon', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::ICONS,
					'default' => [
						'value' => 'fab fa-facebook-f',
						'library' => 'all',
					],
				]
			);

			$repeater->add_control(
				'social_link',
				[
					'label' => esc_html__( 'Link', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::URL,
					'placeholder' => esc_html__( 'https://your-link.com', 'vedhak' ),
					'options' => [ 'url', 'is_external', 'nofollow' ],
					'default' => [
						'url' => '#',
						'is_external' => true,
						'nofollow' => false,
					],
				]
			);

			$this->add_control(
				'social',
				[
					'label'		=> esc_html__( 'Social', 'vedhak' ),
					'type'		=> Controls_Manager::REPEATER,
					'fields'  	=> $repeater->get_controls(),
					'default' 	=> 
						[
							[
								'icon_title' => esc_html__('Facebook','vedhak'),
								'social_link' => [
									'url' => 'https://www.facebook.com',
								],
							],
							[
								'icon_title' => esc_html__('Twitter','vedhak'),
								'social_icon' => [
									'value'    => 'fab fa-twitter',
									'library'  => 'all',
								],
								'social_link' => [
									'url' => 'https://twitter.com/',
								],	
							],
							[
								'icon_title' => esc_html__('Instagram','vedhak'),
								'social_icon' => [
									'value'    => 'ovaicon ovaicon-instagram',
									'library'  => 'ovaicon',
								],
								'social_link' => [
									'url' => 'https://www.instagram.com/',
								],
							],
							[
								'icon_title' => esc_html__('LinkedIn','vedhak'),
								'social_icon' => [
									'value'    => 'flaticon flaticon-019-linkedin',
									'library'  => 'flaticon',
								],
								'social_link' => [
									'url' => 'https://www.linkedin.com/',
								],
							],
						],
					'title_field' => '{{{ icon_title }}}',
				]
			);

			$this->add_control(
				'text_align',
				[
					'label' => esc_html__( 'Alignment', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::CHOOSE,
					'options' => [
						'left' => [
							'title' => esc_html__( 'Left', 'vedhak' ),
							'icon' => 'eicon-text-align-left',
						],
						'center' => [
							'title' => esc_html__( 'Center', 'vedhak' ),
							'icon' => 'eicon-text-align-center',
						],
						'right' => [
							'title' => esc_html__( 'Right', 'vedhak' ),
							'icon' => 'eicon-text-align-right',
						],
					],
					'default' => 'center',
					'toggle' => true,
					'selectors' => [
						'{{WRAPPER}} .ova-our-team' => 'text-align: {{VALUE}};',
					],
				]
			);

		$this->end_controls_section();

		$this->start_controls_section(
			'wrap_image_tab',
			[
				'label' => esc_html__( 'Wrap Image', 'vedhak' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);
			
			$this->add_control(
				'wrap_image_color_overlay',
				[
					'label' => esc_html__( 'Color Hover Overlay', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-our-team:hover .author-image .author-overlay' => 'background-color: {{VALUE}}',
					],
				]
			);

			$this->add_control(
				'wrap_image_border-radius',
				[
					'label' => esc_html__( 'Border Radius', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em' ],
					'selectors' => [
						'{{WRAPPER}} .ova-our-team .author-image' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'wrap_image_margin',
				[
					'label' => esc_html__( 'Margin', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em' ],
					'selectors' => [
						'{{WRAPPER}} .ova-our-team .author-image' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();

		$this->start_controls_section(
			'social_tab',
			[
				'label' => esc_html__( 'Social', 'vedhak' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_control(
				'social_size',
				[
					'label' => esc_html__( 'Icon Size', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%'],
					'range' => [
						'px' => [
							'min' => 10,
							'max' => 60,
							'step' => 1,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-our-team .author-image .social a i' => 'font-size: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'social_spacing',
				[
					'label' => esc_html__( 'Spacing', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%'],
					'range' => [
						'px' => [
							'min' => 10,
							'max' => 50,
							'step' => 1,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-our-team .author-image .social' => 'gap: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'social_color',
				[
					'label' => esc_html__( 'Color', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-our-team .author-image .social a i' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_control(
				'social_color_hover',
				[
					'label' => esc_html__( 'Color Hover', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-our-team .author-image .social a:hover i' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_control(
				'social_background_color',
				[
					'label' => esc_html__( 'Background Color', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-our-team .author-image .social' => 'background-color: {{VALUE}}',
					],
				]
			);

			$this->add_responsive_control(
				'social_padding',
				[
					'label' => esc_html__( 'Padding', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em' ],
					'selectors' => [
						'{{WRAPPER}} .ova-our-team .author-image .social ' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'social_margin',
				[
					'label' => esc_html__( 'Margin', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em' ],
					'selectors' => [
						'{{WRAPPER}} .ova-our-team .author-image .social ' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'social_border_radius',
				[
					'label' => esc_html__( 'Border Radius', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em' ],
					'selectors' => [
						'{{WRAPPER}} .ova-our-team .author-image .social ' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();

		$this->start_controls_section(
			'name_tab',
			[
				'label' => esc_html__( 'Name', 'vedhak' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'name_typography',
					'selector' => '{{WRAPPER}} .ova-our-team .author-info .name',
				]
			);

			$this->add_control(
				'name_color',
				[
					'label' => esc_html__( 'Color', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-our-team .author-info .name' => 'color: {{VALUE}}',
					],
				]
			);
			
			$this->add_control(
				'name_color_hover',
				[
					'label' => esc_html__( 'Color Hover', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-our-team .author-info a:hover .name' => 'color: {{VALUE}}',
					],
					'condition' => [
						'link[url]!' => '',
					],
				]
			);

			$this->add_responsive_control(
				'name_margin',
				[
					'label' => esc_html__( 'Margin', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em' ],
					'selectors' => [
						'{{WRAPPER}} .ova-our-team .author-info .name' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();

		$this->start_controls_section(
			'job_tab',
			[
				'label' => esc_html__( 'Job', 'vedhak' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'job_typography',
					'selector' => '{{WRAPPER}} .ova-our-team .author-info .job',
				]
			);

			$this->add_control(
				'job_color',
				[
					'label' => esc_html__( 'Color', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-our-team .author-info .job' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_responsive_control(
				'job_margin',
				[
					'label' => esc_html__( 'Margin', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em' ],
					'selectors' => [
						'{{WRAPPER}} .ova-our-team .author-info .job' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();

	}

	// Render Template Here
	protected function render() {

		$settings = $this->get_settings();

		$image_url 	   =  $settings['image']['url'];
		$name	       =  $settings['name'];
		$link	   	   =  $settings['link'];
		$nofollow  	=    ( isset( $link['nofollow'] ) && $link['nofollow'] ) ? ' rel="nofollow"' : '';
		$target	    =    ( isset(  $link['is_external'] ) &&  $link['is_external'] == 'on' ) ? '_blank' : '_self';
		$job           =  $settings['job'];
		$social        =  $settings['social'];

		$image_alt 	   =  ( isset( $settings['image']['alt']) &&  $settings['image']['alt'] != '' ) ?  $settings['image']['alt'] : $name;

		?>

			<div class="ova-our-team ">

				<div class="author-image">

					<?php if( !empty($link['url']) ) { ?>
						<a href="<?php echo esc_attr($link['url']); ?>" target="<?php echo esc_attr( $target ); ?>" <?php printf( $nofollow ); ?> >
					<?php } ?>

						<img src="<?php echo esc_attr( $image_url ); ?>" alt="<?php echo esc_attr( $image_alt ); ?>">

						<div class="author-overlay"></div>

					<?php if( !empty($link['url']) ) { ?>
						</a>
					<?php } ?>

					<?php if(!empty($social)) { ?>

						<div class="social ">

							<?php foreach($social as $icon){

								$social_icon 			=	 $icon['social_icon']['value'];
								$social_link 			=	 $icon['social_link']['url'];
								$social_link_nofollow  	=    ( isset( $icon['social_link']['nofollow'] ) && $icon['social_link']['nofollow'] ) ? ' rel="nofollow"' : '';
			               		$social_link_target	    =    ( isset(  $icon['social_link']['is_external'] ) &&  $icon['social_link']['is_external'] == 'on' ) ? '_blank' : '_self'; 
								?>

								<?php if(!empty($social_link)) { ?>

									<a href="<?php echo esc_attr($social_link); ?>" target="<?php echo esc_attr( $social_link_target ); ?>" <?php printf($social_link_nofollow); ?> >

									  	<i class="<?php echo esc_attr($social_icon) ?>"></i>

									</a>

								<?php } ?>

							<?php } ?>

						</div>

					<?php } ?>

				</div>
				
				<div class="author-info ">

					<?php if( $name ) : ?>

						<?php if( !empty($link['url']) ) { ?>
							<a href="<?php echo esc_attr($link['url']); ?>" target="<?php echo esc_attr( $target ); ?>" <?php printf( $nofollow ); ?> >
						<?php } ?>

							<h3 class="name"><?php echo esc_html( $name ); ?></h3>

						<?php if( !empty($link['url']) ) { ?>
							</a>
						<?php } ?>

					<?php endif; ?>

					<?php if( $job ) : ?>
						<p class="job">
							<?php echo esc_html( $job ) ?>
						</p>
					<?php endif; ?>

				</div>

			</div>

		<?php
	}
}
$widgets_manager->register( new Vedhak_Elementor_Our_Team() );