<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Vedhak_Elementor_Progress extends Widget_Base {

	public function get_name() {
		return 'vedhak_elementor_progress';
	}

	public function get_title() {
		return esc_html__( 'Ova Progress', 'vedhak' );
	}

	public function get_icon() {
		return 'eicon-skill-bar';
	}

	public function get_categories() {
		return [ 'vedhak' ];
	}

	public function get_script_depends() {

		// appear js
		wp_enqueue_script( 'appear', get_theme_file_uri('/assets/libs/appear/appear.js'), array('jquery'), false, true);
		
		return [ 'vedhak-elementor-progress' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		/* Begin progress */
		$this->start_controls_section(
			'section_progress',
			[
				'label' => esc_html__( 'Progress', 'vedhak' ),
			]
		);

			$this->add_control(
				'title',
				[
					'label' 		=> esc_html__( 'Title', 'vedhak' ),
					'type' 			=> Controls_Manager::TEXT,
					'placeholder' 	=> esc_html__( 'Enter your title', 'vedhak' ),
					'default' 		=> esc_html__( 'Saticfied Clients', 'vedhak' ),
					'label_block' 	=> true,
				]
			);

			$this->add_control(
				'percent',
				[
					'label' 	=> esc_html__( 'Percent', 'vedhak' ),
					'type' 		=> Controls_Manager::NUMBER,
					'min' 		=> 0,
					'max' 		=> 100,
					'step' 		=> 1,
					'default' 	=> 89,
				]
			);

			$this->add_control(
	            'show_percent',
	            [
	                'label' 	=> esc_html__( 'Show Percent', 'vedhak' ),
	                'type' 		=> Controls_Manager::SWITCHER,
	                'default' 	=> 'yes',
	            ]
	        );

	        $this->add_control(
	            'show_dot',
	            [
	                'label' 	=> esc_html__( 'Show Dot', 'vedhak' ),
	                'type' 		=> Controls_Manager::SWITCHER,
	                'default' 	=> 'yes',
	            ]
	        );

		$this->end_controls_section();
		/* End progress */

		/* Begin general style */
		$this->start_controls_section(
			'section_general_style',
			[
				'label' => esc_html__( 'General', 'vedhak' ),
				'tab' 	=> Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_control(
				'general_background_color',
				[
					'label' => esc_html__( 'Background Color', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-progress' => 'background-color: {{VALUE}}',
					],
				]
			);

			$this->add_responsive_control(
	            'general_padding',
	            [
	                'label' 		=> esc_html__( 'Padding', 'vedhak' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-progress' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

			$this->add_group_control(
				\Elementor\Group_Control_Box_Shadow::get_type(),
				[
					'name' => 'general_box_shadow',
					'selector' => '{{WRAPPER}} .ova-progress',
				]
			);

		$this->end_controls_section();
		/* End general */

		/* Begin title style */
		$this->start_controls_section(
			'section_title_style',
			[
				'label' => esc_html__( 'Title', 'vedhak' ),
				'tab' 	=> Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'title_typography',
					'selector' 	=> '{{WRAPPER}} .ova-progress .ova-progress-title',
				]
			);

			$this->add_control(
				'title_color',
				[
					'label' 	=> esc_html__( 'Color', 'vedhak' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-progress .ova-progress-title' => 'color: {{VALUE}};',
					],
				]
			);

	        $this->add_responsive_control(
	            'title_margin',
	            [
	                'label' 		=> esc_html__( 'Margin', 'vedhak' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-progress .ova-progress-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

		$this->end_controls_section();
		/* End title style */

		/* Begin percentage style */
		$this->start_controls_section(
			'section_percentage_style',
			[
				'label' => esc_html__( 'Percentage', 'vedhak' ),
				'tab' 	=> Controls_Manager::TAB_STYLE,
				'condition' => [
					'show_percent' => 'yes',
				],
			]
		);

		    $this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'percentage_typography',
					'selector' 	=> '{{WRAPPER}} .ova-progress .ova-percent-view .percentage',
				]
			);

			$this->add_control(
				'percentage_color',
				[
					'label' 	=> esc_html__( 'Color', 'vedhak' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-progress .ova-percent-view .percentage' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_responsive_control(
				'percentage_bottom',
				[
					'label' 		=> esc_html__( 'Bottom', 'vedhak' ),
					'type' 			=> Controls_Manager::SLIDER,
					'size_units' 	=> [ 'px', '%' ],
					'range' => [
						'px' => [
							'min' 	=> -100,
							'max' 	=> 100,
							'step' 	=> 5,
						],
						'%' => [
							'min' 	=> -100,
							'max' 	=> 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-progress .ova-percent-view .percentage' => 'bottom: {{SIZE}}{{UNIT}}',
					],
				]
			);

		$this->end_controls_section();
		/* End percentage style */

		/* Begin progress style */
		$this->start_controls_section(
			'section_progress_style',
			[
				'label' => esc_html__( 'Progress Bar', 'vedhak' ),
				'tab' 	=> Controls_Manager::TAB_STYLE,
			]
		);      

			$this->add_responsive_control(
				'progress_height',
				[
					'label' 	=> esc_html__( 'Height', 'vedhak' ),
					'type' 		=> Controls_Manager::SLIDER,
					'selectors' => [
						'{{WRAPPER}} .ova-progress .ova-percent-view' => 'height: {{SIZE}}{{UNIT}}',
					],
				]
			);

			$this->add_control(
				'progress_bg',
				[
					'label' 	=> esc_html__( 'Background', 'vedhak' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-progress .ova-percent-view' => 'background-color: {{VALUE}};',
					],
				]
			);

	        $this->add_control(
	            'progress_border_radius',
	            [
	                'label' 		=> esc_html__( 'Border Radius', 'vedhak' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-progress .ova-percent-view' 				=> 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                    '{{WRAPPER}} .ova-progress .ova-percent-view .ova-percent' 	=> 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

		$this->end_controls_section();
		/* End progress style */

		/* Begin percent style */
		$this->start_controls_section(
			'section_percent_style',
			[
				'label' => esc_html__( 'Percent Bar', 'vedhak' ),
				'tab' 	=> Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_responsive_control(
				'percent_height',
				[
					'label' 	=> esc_html__( 'Height', 'vedhak' ),
					'type' 		=> Controls_Manager::SLIDER,
					'selectors' => [
						'{{WRAPPER}} .ova-progress .ova-percent-view .ova-percent' => 'height: {{SIZE}}{{UNIT}}',
					],
				]
			);

			$this->add_control(
				'percent_bg',
				[
					'label' 	=> esc_html__( 'Background', 'vedhak' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-progress .ova-percent-view .ova-percent' => 'background: {{VALUE}};',
					],
				]
			);

		$this->end_controls_section();
		/* End percent style */

		/* Begin dot style */
		$this->start_controls_section(
			'section_dot_style',
			[
				'label' => esc_html__( 'Dot', 'vedhak' ),
				'tab' 	=> Controls_Manager::TAB_STYLE,
				'condition' => [
					'show_dot' => 'yes',
				],
			]
		);

			$this->add_responsive_control(
				'dot_size',
				[
					'label' 	=> esc_html__( 'Size', 'vedhak' ),
					'type' 		=> Controls_Manager::SLIDER,
					'selectors' => [
						'{{WRAPPER}} .ova-progress .ova-percent-view .ova-dot' => 'height: {{SIZE}}{{UNIT}};width: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'dot_background_color',
				[
					'label' 	=> esc_html__( 'Color', 'vedhak' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-progress .ova-percent-view .ova-dot' => 'background-color: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'dot_border_radius',
				[
					'label' => esc_html__( 'Border Radius', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'selectors' => [
						'{{WRAPPER}} .ova-progress .ova-percent-view .ova-dot' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();
		/* End dot style */
	}

	// Render Template Here
	protected function render() {
		$settings = $this->get_settings();

		$title 				= $settings['title'];
		$percent 			= $settings['percent'];
		$show_percent 		= $settings['show_percent'];
		$show_dot 		    = $settings['show_dot'];

		?>

		<div class="ova-progress">
			<?php if ( $title !== '' ): ?>
				<h4 class="ova-progress-title"><?php echo esc_html( $title ); ?></h4>
			<?php endif; ?>
			<div class="ova-percent-view" >
				<?php if( $show_percent == 'yes' ) : ?>
					<span class="percentage" >
						<?php echo esc_html( $percent ).esc_html('%','vedhak'); ?>
					</span>
				<?php endif; ?>

				<div class="ova-percent" data-percent="<?php echo esc_html( $percent ); ?>"></div>

				<?php if( $show_dot == 'yes' ) : ?>
					<div class="ova-dot"></div>	
				<?php endif; ?>
			</div>
		</div>
		 	
		<?php
	}
}
$widgets_manager->register( new Vedhak_Elementor_Progress() );