<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Vedhak_Elementor_Testimonial extends Widget_Base {

	public function get_name() {
		return 'vedhak_elementor_testimonial';
	}

	public function get_title() {
		return esc_html__( 'Ova Testimonial', 'vedhak' );
	}

	public function get_icon() {
		return 'eicon-testimonial-carousel';
	}

	public function get_categories() {
		return [ 'vedhak' ];
	}

	public function get_script_depends() {
		// Carousel
		wp_enqueue_script('carousel', VEDHAK_URI.'/assets/libs/carousel/owl.carousel.min.js', array('jquery'),null,true);
		wp_enqueue_style('carousel', VEDHAK_URI.'/assets/libs/carousel/assets/owl.carousel.min.css', array(), null);
		
		return [ 'vedhak-elementor-testimonial' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'vedhak' ),
			]
		);	
			
			$this->add_control(
				'template',
				[
					'label' => esc_html__( 'Template', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'default' => 'template1',
					'options' => [
						'template1' => esc_html__( 'Template 1', 'vedhak' ),
						'template2' => esc_html__( 'Template 2', 'vedhak' ),
						'template3' => esc_html__( 'Template 3', 'vedhak' ),
					],
				]
			);

			$this->add_control(
				'icon',
				[
					'label' => esc_html__( 'Icon Quote', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::ICONS,
					'default' => [
						'value' => 'flaticon flaticon-quotes',
						'library' => 'flaticon',
					],
					'condition' => [
						'template!' => 'template1',
						'show_background_quote' => 'yes',
					],
				]
			);

			$this->add_control(
				'show_background_quote',
				[
					'label' => esc_html__( 'Show Background Quote', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => esc_html__( 'Show', 'vedhak' ),
					'label_off' => esc_html__( 'Hide', 'vedhak' ),
					'return_value' => 'yes',
					'default' => 'yes',
					'condition' => [
						'template!' => 'template1',
					],
				]
			);
			
			// Add Class control
			$repeater = new \Elementor\Repeater();

			$repeater->add_control(
				'content',
				[
					'label' => esc_html__( 'Content', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::TEXTAREA,
					'default' => esc_html__( 'Sit amet consectetur adipiscing congue pose habit ante dignissim faucibus tincidunt vulputate ullamcorper mattis quisque esta sidiculus', 'vedhak' ),
					'placeholder' => esc_html__( 'Type your content here', 'vedhak' ),
				]
			);

			$repeater->add_control(
				'author',
				[
					'label' => esc_html__( 'Author', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::MEDIA,
					'default' => [
						'url' => \Elementor\Utils::get_placeholder_image_src(),
					],
					'separator' => 'before',
				]
			);

			$repeater->add_control(
				'name',
				[
					'label' => esc_html__( 'Name', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::TEXT,
					'default' => esc_html__( 'Default title', 'vedhak' ),
					'placeholder' => esc_html__( 'Type your title here', 'vedhak' ),
				]
			);

			$repeater->add_control(
				'job',
				[
					'label' => esc_html__( 'Job', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::TEXT,
					'default' => esc_html__( 'Default title', 'vedhak' ),
					'placeholder' => esc_html__( 'Type your title here', 'vedhak' ),
				]
			);

			$this->add_control(
				'items_testimonial',
				[
					'label' => esc_html__( 'Items Testimonial', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::REPEATER,
					'fields' => $repeater->get_controls(),
					'default' => [
						[
							'name' => esc_html__( 'Malcolm K. Monks', 'vedhak' ),
							'job' => esc_html__( 'CEO & Founder', 'vedhak' ),
						],
						[
							'name' => esc_html__( 'Hubert J. Johnso', 'vedhak' ),
							'job' => esc_html__( 'CEO & Founder', 'vedhak' ),
						],
						[
							'name' => esc_html__( 'Pacific D. Lee', 'vedhak' ),
							'job' => esc_html__( 'CEO & Founder', 'vedhak' ),
						],
					],
					'title_field' => '{{{ name }}}',
				]
			);

			$this->add_control(
				'show_rating',
				[
					'label'   => esc_html__( 'Show Rating', 'vedhak' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
					'options' => [
						'yes' => esc_html__( 'Yes', 'vedhak' ),
						'no'  => esc_html__( 'No', 'vedhak' ),
					],
				]
			);

		$this->end_controls_section();

		/*****************************************************************
						START SECTION ADDITIONAL
		******************************************************************/

		$this->start_controls_section(
			'section_additional_options',
			[
				'label' => esc_html__( 'Additional Options', 'vedhak' ),
			]
		);

			$this->add_control(
				'slides_to_scroll',
				[
					'label'       => esc_html__( 'Slides to Scroll', 'vedhak' ),
					'type'        => Controls_Manager::NUMBER,
					'description' => esc_html__( 'Set how many slides are scrolled per swipe.', 'vedhak' ),
					'default'     => 1,
				]
			);

			$this->add_control(
				'pause_on_hover',
				[
					'label'   => esc_html__( 'Pause on Hover', 'vedhak' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
					'options' => [
						'yes' => esc_html__( 'Yes', 'vedhak' ),
						'no'  => esc_html__( 'No', 'vedhak' ),
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'infinite',
				[
					'label'   => esc_html__( 'Infinite Loop', 'vedhak' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
					'options' => [
						'yes' => esc_html__( 'Yes', 'vedhak' ),
						'no'  => esc_html__( 'No', 'vedhak' ),
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'autoplay',
				[
					'label'   => esc_html__( 'Autoplay', 'vedhak' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
					'options' => [
						'yes' => esc_html__( 'Yes', 'vedhak' ),
						'no'  => esc_html__( 'No', 'vedhak' ),
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'autoplay_speed',
				[
					'label'     => esc_html__( 'Autoplay Speed', 'vedhak' ),
					'type'      => Controls_Manager::NUMBER,
					'default'   => 3000,
					'step'      => 500,
					'condition' => [
						'autoplay' => 'yes',
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'smartspeed',
				[
					'label'   => esc_html__( 'Smart Speed', 'vedhak' ),
					'type'    => Controls_Manager::NUMBER,
					'default' => 500,
				]
			);

			$this->add_control(
				'dot_control',
				[
					'label'   => esc_html__( 'Show Dots', 'vedhak' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
					'options' => [
						'yes' => esc_html__( 'Yes', 'vedhak' ),
						'no'  => esc_html__( 'No', 'vedhak' ),
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'nav_control',
				[
					'label'   => esc_html__( 'Show Nav', 'vedhak' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
					'options' => [
						'yes' => esc_html__( 'Yes', 'vedhak' ),
						'no'  => esc_html__( 'No', 'vedhak' ),
					],
					'frontend_available' => true,
				]
			);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_general_style',
			[
				'label' => esc_html__( 'General', 'vedhak' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_control(
				'general_background_color',
				[
					'label' => esc_html__( 'Background Color', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .item' => 'background-color: {{VALUE}}',
					],
				]
			);


			$this->add_responsive_control(
				'general_padding',
				[
					'label' => esc_html__( 'Padding', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em'],
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'general_margin',
				[
					'label' => esc_html__( 'Margin', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em'],
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .item' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Border::get_type(),
				[
					'name' => 'general_border',
					'selector' => '{{WRAPPER}} .ova-testimonial .slide-testimonials .item',
				]
			);

			$this->add_control(
				'general_border_radius',
				[
					'label' => esc_html__( 'Border Radius', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em'],
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .item' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_author_style',
			[
				'label' => esc_html__( 'Image', 'vedhak' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_responsive_control(
				'author_image_size',
				[
					'label' => esc_html__( 'Size', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 500,
							'step' => 1,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .item .author .image img' => 'width: {{SIZE}}{{UNIT}};min-width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'author_image_border_radius',
				[
					'label' => esc_html__( 'Border Radius', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em'],
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .item .author .image img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'author_image_margin',
				[
					'label' => esc_html__( 'Margin', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em'],
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .item .author .image ,{{WRAPPER}}  .ova-testimonial.template3 .owl-carousel .owl-stage-outer .item .author' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_rating',
			[
				'label' => esc_html__( 'Rating', 'vedhak' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
				'condition' => [
					'show_rating' => 'yes',
				],
			]
		);

			$this->add_responsive_control(
				'rating_size',
				[
					'label' => esc_html__( 'Size', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 100,
							'step' => 1,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .item .rating i' => 'font-size: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'rating_spacing',
				[
					'label' => esc_html__( 'Spacing', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 100,
							'step' => 1,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .item .rating i' => 'margin-right: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'rating_color',
				[
					'label' => esc_html__( 'Color', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .item .rating i' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_responsive_control(
				'rating_margin',
				[
					'label' => esc_html__( 'Margin', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em'],
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial .item .rating' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_name',
			[
				'label' => esc_html__( 'Name', 'vedhak' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'name_typography',
					'selector' => '{{WRAPPER}} .ova-testimonial .slide-testimonials .item .info .name',
				]
			);

			$this->add_control(
				'name_color',
				[
					'label' => esc_html__( 'Color', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .item .info .name' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_responsive_control(
				'name_margin',
				[
					'label' => esc_html__( 'Margin', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em'],
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .item .info .name' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_job',
			[
				'label' => esc_html__( 'Job', 'vedhak' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'job_typography',
					'selector' => '{{WRAPPER}} .ova-testimonial .slide-testimonials .item .info .job',
				]
			);

			$this->add_control(
				'job_color',
				[
					'label' => esc_html__( 'Color', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .item .info .job' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_responsive_control(
				'job_margin',
				[
					'label' => esc_html__( 'Margin', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em'],
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .item .info .job' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_testimonial_content',
			[
				'label' => esc_html__( 'Content', 'vedhak' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'content_typography',
					'selector' => '{{WRAPPER}} .ova-testimonial .item .content , {{WRAPPER}} .ova-testimonial.template3 .owl-carousel .owl-stage-outer .item .info .content ',
				]
			);

			$this->add_control(
				'content_color',
				[
					'label' => esc_html__( 'Color', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial .item .content ' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_responsive_control(
				'content_margin',
				[
					'label' => esc_html__( 'Margin', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em'],
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial .item .content , {{WRAPPER}} .ova-testimonial.template3 .owl-carousel .owl-stage-outer .item .info .content ' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_quote_style',
			[
				'label' => esc_html__( 'Quote', 'vedhak' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
				'condition' => [
					'template!' => 'template1',
					'show_background_quote' => 'yes',
				],
			]
		);

			$this->add_responsive_control(
				'quote_size',
				[
					'label' => esc_html__( 'Size', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 500,
							'step' => 1,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial .item .quote i' => 'font-size: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'quote_color',
				[
					'label' => esc_html__( 'Color', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial .item .quote i' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_responsive_control(
				'quote_position_top',
				[
					'label' => esc_html__( 'Top Position', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 500,
							'step' => 1,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial .item .quote' => 'top: {{SIZE}}{{UNIT}};',
					],
					'condition' => [
						'template' => 'template3',
					],
				]
			);

			$this->add_responsive_control(
				'quote_position_right',
				[
					'label' => esc_html__( 'Right Position', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1000,
							'step' => 1,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial .item .quote' => 'right: {{SIZE}}{{UNIT}};',
					],
					'condition' => [
						'template' => 'template3',
					],
				]
			);

			$this->add_responsive_control(
				'quote_position_margin',
				[
					'label'      => esc_html__( 'Margin', 'vedhak' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-testimonial .item .quote' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
					'condition' => [
						'template' => 'template2',
					],
				]
			);

		$this->end_controls_section();

		/* Begin Dots Style */
		$this->start_controls_section(
            'dots_style',
            [
                'label' => esc_html__( 'Dots', 'vedhak' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
                'condition' => [
					'dot_control' => 'yes',
				]
            ]
        );

        	$this->add_responsive_control(
				'dots_width',
				[
					'label' 	=> esc_html__( 'Width', 'vedhak' ),
					'type' 		=> Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'size_units' 	=> [ 'px' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-testimonial .owl-carousel .owl-dots .owl-dot' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
	            'dots_border_radius',
	            [
	                'label' 		=> esc_html__( 'Border Radius', 'vedhak' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-testimonial .owl-carousel .owl-dots .owl-dot' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

	        $this->add_control(
				'dots_heading_normal',
				[
					'label' => esc_html__( 'Dots Normal', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

			$this->add_control(
				'dots_color',
				[
					'label' 	=> esc_html__( 'Color', 'vedhak' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial .owl-carousel .owl-dots .owl-dot' => 'background-color: {{VALUE}}',
					],
				]
			);

			$this->add_responsive_control(
	            'dots_margin',
	            [
	                'label' 		=> esc_html__( 'Margin', 'vedhak' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-testimonial .owl-carousel .owl-dots .owl-dot' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

			$this->add_control(
				'dots_heading_active',
				[
					'label' => esc_html__( 'Dots Active', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

			$this->add_control(
				'dots_color_active',
				[
					'label' 	=> esc_html__( 'Color', 'vedhak' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-testimonial .owl-carousel .owl-dots .owl-dot.active' => 'background-color: {{VALUE}}',
					],
				]
			);

			$this->add_responsive_control(
	            'dots_margin_active',
	            [
	                'label' 		=> esc_html__( 'Margin', 'vedhak' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-testimonial .owl-carousel .owl-dots .owl-dot.active' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

	        $this->add_control(
				'heading_dots_border_active',
				[
					'label' => esc_html__( 'Border Active', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

	        $this->add_responsive_control(
				'dots_active_border_size',
				[
					'label' 	=> esc_html__( ' Size', 'vedhak' ),
					'type' 		=> Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'size_units' 	=> [ 'px' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-testimonial .owl-carousel .owl-dots .owl-dot.active:after' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
					],
				]
			);

	        $this->add_group_control(
				\Elementor\Group_Control_Border::get_type(),
				[
					'name' => 'dot_active_border',
					'selector' => '{{WRAPPER}} .ova-testimonial .owl-carousel .owl-dots .owl-dot.active:after',
				]
			);

			$this->add_control(
	            'active_dots_border_radius',
	            [
	                'label' 		=> esc_html__( 'Border Radius', 'vedhak' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%' ],
	                'selectors' 	=> [
	                    ' {{WRAPPER}} .ova-testimonial .owl-carousel .owl-dots .owl-dot.active:after' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

	        $this->add_control(
				'dots_heading_position',
				[
					'label' => esc_html__( 'Position', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

			$this->add_responsive_control(
				'dots_right',
				[
					'label' 	=> esc_html__( 'Right', 'vedhak' ),
					'type' 		=> Controls_Manager::SLIDER,
					'size_units' 	=> [ 'px', '%', 'em', 'rem' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1000,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-testimonial .owl-carousel .owl-dots' => 'right: {{SIZE}}{{UNIT}};left:unset;',
					],
				]
			);

			$this->add_responsive_control(
				'dots_left',
				[
					'label' 	=> esc_html__( 'Left', 'vedhak' ),
					'type' 		=> Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1000,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'size_units' 	=> [ 'px' , '%', 'em', 'rem' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-testimonial .owl-carousel .owl-dots' => 'left: {{SIZE}}{{UNIT}};right:unset;',
					],
					'condition' => [
						'template' => 'template1',
					],
				]
			);

			$this->add_responsive_control(
				'dots_bottom',
				[
					'label' 	=> esc_html__( 'Bottom', 'vedhak' ),
					'type' 		=> Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1000,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'size_units' 	=> [ 'px', '%', 'em', 'rem'  ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-testimonial .owl-carousel .owl-dots' => 'bottom: {{SIZE}}{{UNIT}}',
					],
				]
			);

        $this->end_controls_section();
        /* End Dots Style */

        /* Begin Nav Style */
		$this->start_controls_section(
            'nav_style',
            [
                'label' => esc_html__( 'Nav Control', 'vedhak' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
                'condition' => [
                	'nav_control' => 'yes',
                ]
            ]
        );
            
            $this->add_responsive_control(
				'size_nav_icon',
				[
					'label' 		=> esc_html__( 'Icon Size', 'vedhak' ),
					'type' 			=> Controls_Manager::SLIDER,
					'size_units' 	=> [ 'px', '%', 'em', 'rem' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 100,
							'step' => 1,
						],
					],
					'selectors' => [
						' {{WRAPPER}} .ova-testimonial .slide-testimonials .owl-nav button i' => 'font-size: {{SIZE}}{{UNIT}};',
					],
				]
			);


			$this->add_responsive_control(
				'nav_button_size',
				[
					'label' 	=> esc_html__( 'Button Size', 'vedhak' ),
					'type' 		=> Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 20,
							'max' => 100,
						],
					],
					'size_units' 	=> [ 'px', '%', 'em', 'rem'  ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-testimonial .slide-testimonials .owl-nav button ' => 'height: {{SIZE}}{{UNIT}}; width:{{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Border::get_type(),
				[
					'name' => 'nav_border',
					'selector' => '{{WRAPPER}} .ova-testimonial .slide-testimonials .owl-nav button',
				]
			);

			$this->add_control(
	            'nav_border_radius',
	            [
	                'label' 		=> esc_html__( 'Border Radius', 'vedhak' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%' ],
	                'selectors' 	=> [
	                    ' {{WRAPPER}} .ova-testimonial .slide-testimonials .owl-nav button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

			$this->start_controls_tabs( 'tabs_nav_style' );
				
				$this->start_controls_tab(
		            'tab_nav_normal',
		            [
		                'label' => esc_html__( 'Normal', 'vedhak' ),
		            ]
		        );

		            $this->add_control(
						'color_nav_icon',
						[
							'label' => esc_html__( 'Icon Color', 'vedhak' ),
							'type' => Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-testimonial .slide-testimonials .owl-nav button i' => 'color : {{VALUE}};',
							],
						]
					);

					$this->add_control(
						'color_nav_border',
						[
							'label' => esc_html__( 'Color Border', 'vedhak' ),
							'type' => Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-testimonial .slide-testimonials .owl-nav button ' => 'border-color : {{VALUE}};',
							],
						]
					);


					$this->add_control(
						'color_nav_background',
						[
							'label' => esc_html__( 'Background Color', 'vedhak' ),
							'type' => Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-testimonial .slide-testimonials .owl-nav button' => 'background-color : {{VALUE}};',
							],
						]
					);

		        $this->end_controls_tab();

		        $this->start_controls_tab(
		            'tab_icon_hover',
		            [
		                'label' => esc_html__( 'Hover', 'vedhak' ),
		            ]
		        );

		            $this->add_control(
						'color_nav_icon_hover',
						[
							'label' => esc_html__( 'Icon Color ', 'vedhak' ),
							'type' => Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-testimonial .slide-testimonials .owl-nav button:hover i' => 'color : {{VALUE}};',
							],
						]
					);

					$this->add_control(
						'color_nav_border_hover',
						[
							'label' => esc_html__( 'Color Border', 'vedhak' ),
							'type' => Controls_Manager::COLOR,
							'selectors' => [
								'.ova-testimonial .slide-testimonials .owl-nav button:hover' => 'border-color : {{VALUE}};',
							],
						]
					);

					$this->add_control(
						'color_nav_background_hover',
						[
							'label' => esc_html__( 'Background Color', 'vedhak' ),
							'type' => Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-testimonial .slide-testimonials .owl-nav button:hover' => 'background-color : {{VALUE}};',
							],
						]
					);

		        $this->end_controls_tab();

		    $this->end_controls_tabs();

		    $this->add_control(
				'nav_position_heading',
				[
					'label' => esc_html__( 'Position', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

		    	$this->add_responsive_control(
					'nav_left',
					[
						'label' 	=> esc_html__( 'Left', 'vedhak' ),
						'type' 		=> Controls_Manager::SLIDER,
						'range' => [
							'px' => [
								'min' => 0,
								'max' => 1000,
							],
							'%' => [
								'min' => 0,
								'max' => 100,
							],
						],
						'size_units' 	=> [ 'px', '%', 'em', 'rem'  ],
						'selectors' 	=> [
							'{{WRAPPER}} .ova-testimonial .slide-testimonials .owl-nav' => 'left: {{SIZE}}{{UNIT}};right:unset',
						],
						'condition' => [
							'template!' => 'template3',
						]
					]
				);

				$this->add_responsive_control(
					'nav_right',
					[
						'label' 	=> esc_html__( 'Right', 'vedhak' ),
						'type' 		=> Controls_Manager::SLIDER,
						'range' => [
							'px' => [
								'min' => 0,
								'max' => 1000,
							],
							'%' => [
								'min' => 0,
								'max' => 100,
							],
						],
						'size_units' 	=> [ 'px', '%', 'em', 'rem'  ],
						'selectors' 	=> [
							'{{WRAPPER}} .ova-testimonial .slide-testimonials .owl-nav' => 'right: {{SIZE}}{{UNIT}};left:unset',
						],
						'condition' => [
							'template' => 'template1',
						]
					]
				);

				$this->add_responsive_control(
					'nav_bottom',
					[
						'label' 	=> esc_html__( 'Bottom', 'vedhak' ),
						'type' 		=> Controls_Manager::SLIDER,
						'range' => [
							'px' => [
								'min' => 0,
								'max' => 1000,
							],
							'%' => [
								'min' => 0,
								'max' => 100,
							],
						],
						'size_units' 	=> [ 'px', '%', 'em', 'rem'  ],
						'selectors' 	=> [
							'{{WRAPPER}} .ova-testimonial .slide-testimonials .owl-nav ,{{WRAPPER}}  .ova-testimonial.template3 .owl-carousel .owl-nav button' => 'bottom: {{SIZE}}{{UNIT}}',
						],
					]
				);

				$this->add_responsive_control(
					'nav_previous_button',
					[
						'label' 	=> esc_html__( 'Previous Button - Left', 'vedhak' ),
						'type' 		=> Controls_Manager::SLIDER,
						'range' => [
							'px' => [
								'min' => 0,
								'max' => 1000,
							],
							'%' => [
								'min' => 0,
								'max' => 100,
							],
						],
						'size_units' 	=> [ 'px', '%', 'em', 'rem'  ],
						'selectors' 	=> [
							'{{WRAPPER}} .ova-testimonial.template3 .owl-carousel .owl-nav button.owl-prev' => 'left: {{SIZE}}{{UNIT}}',
						],
						'condition' => [
							'template' => 'template3',
						]
					]
				);

				$this->add_responsive_control(
					'nav_next_button',
					[
						'label' 	=> esc_html__( 'Next Button - Right', 'vedhak' ),
						'type' 		=> Controls_Manager::SLIDER,
						'range' => [
							'px' => [
								'min' => 0,
								'max' => 1000,
							],
							'%' => [
								'min' => 0,
								'max' => 100,
							],
						],
						'size_units' 	=> [ 'px', '%', 'em', 'rem'  ],
						'selectors' 	=> [
							'{{WRAPPER}} .ova-testimonial.template3 .owl-carousel .owl-nav button.owl-next' => 'right: {{SIZE}}{{UNIT}}',
						],
						'condition' => [
							'template' => 'template3',
						]
					]
				);

				$this->add_responsive_control(
		            'nav_margin',
		            [
		                'label' 		=> esc_html__( 'Margin', 'vedhak' ),
		                'type' 			=> Controls_Manager::DIMENSIONS,
		                'size_units' 	=> [ 'px', '%' ],
		                'selectors' 	=> [
		                    ' {{WRAPPER}} .ova-testimonial .owl-carousel .owl-nav button.owl-prev' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
		                ],
		                'condition' => [
							'template!' => 'template3',
						]
		            ]
		        );

        $this->end_controls_section();
        /* End Nav Style */
	}

	// Render Template Here
	protected function render() {
		$settings = $this->get_settings();

		$template  = $settings['template'];
		$items_testimonial = $settings['items_testimonial'];

		$icon = $settings['icon']['value'];
		$show_background_quote = $settings['show_background_quote'];

		$show_rating = $settings['show_rating'];
				
		$data_options['slideBy']            = $settings['slides_to_scroll'];
		$data_options['autoplayHoverPause'] = $settings['pause_on_hover'] === 'yes' ? true : false;
		$data_options['loop']               = $settings['infinite'] === 'yes' ? true : false;
		$data_options['autoplay']           = $settings['autoplay'] === 'yes' ? true : false;
		$data_options['autoplayTimeout']    = $settings['autoplay_speed'];
		$data_options['smartSpeed']         = $settings['smartspeed'];
		$data_options['dots']               = $settings['dot_control'] === 'yes' ? true : false;
		$data_options['nav']                = $settings['nav_control'] === 'yes' ? true : false;

		?>

			<div class="ova-testimonial <?php echo esc_attr($template); ?>">
				<div class="slide-testimonials owl-carousel owl-theme" data-options="<?php echo esc_attr(json_encode($data_options)); ?>" >
					<?php if ($items_testimonial ) { ?>

						<?php foreach ($items_testimonial as $items) { 
							$image_alt = (isset($items['author']['alt']) && $items['author']['alt'] != '') ? $items['author']['alt'] : $items['name']; 
						?>
							<div class="item">

								<?php if( $template == 'template1') : ?>

									<div class="author">
											
										<?php if( !empty( $items['author']['url']) ) : ?>
											<div class="image">

												<img src="<?php echo esc_url($items['author']['url']); ?>" alt="<?php echo esc_attr($image_alt); ?>">

											</div>
										<?php endif; ?>

										<div class="info">

											<?php if( !empty( $items['name'] ) ) : ?>
												<h3 class="name"><?php echo esc_html($items['name']); ?></h3>
											<?php endif; ?>

											<?php if( !empty( $items['job'] ) ) : ?>
												<p class="job"><?php echo esc_html($items['job']); ?></p>
											<?php endif; ?>

										</div>

									</div>

									<?php if( !empty( $items['content'] ) ) : ?>
										<p class="content"><?php echo esc_html($items['content']); ?></p>
									<?php endif; ?>

									<?php if( $show_rating == 'yes') : ?>
										<div class="rating">
											<i aria-hidden="true" class="fas fa-star"></i>
											<i aria-hidden="true" class="fas fa-star"></i>
											<i aria-hidden="true" class="fas fa-star"></i>
											<i aria-hidden="true" class="fas fa-star"></i>
											<i aria-hidden="true" class="fas fa-star"></i>
										</div>
									<?php endif; ?>
									
								<?php endif; ?>


								<?php if( $template == 'template2') : ?>

									<?php if( !empty( $icon ) && $show_background_quote == 'yes' ) : ?>
										<div class="quote">
											<i class="<?php echo esc_attr( $icon ); ?>"></i>
										</div>
									<?php endif; ?>
										
									<?php if( !empty( $items['content'] ) ) : ?>
										<p class="content"><?php echo esc_html( $items['content']); ?></p>
									<?php endif; ?>

									<div class="author">
										
										<?php if( !empty( $items['author']['url']) ) : ?>
											<div class="image">

												<img src="<?php echo esc_url($items['author']['url']); ?>" alt="<?php echo esc_attr($image_alt); ?>">

											</div>
										<?php endif; ?>

										<div class="info">

											<?php if( !empty( $items['name'] ) ) : ?>
												<h3 class="name"><?php echo esc_html($items['name']); ?></h3>
											<?php endif; ?>

											<?php if( !empty( $items['job'] ) ) : ?>
												<p class="job"><?php echo esc_html($items['job']); ?></p>
											<?php endif; ?>

											<?php if( $show_rating == 'yes') : ?>
												<div class="rating">
													<i aria-hidden="true" class="fas fa-star"></i>
													<i aria-hidden="true" class="fas fa-star"></i>
													<i aria-hidden="true" class="fas fa-star"></i>
													<i aria-hidden="true" class="fas fa-star"></i>
													<i aria-hidden="true" class="fas fa-star"></i>
												</div>
											<?php endif; ?>
											
										</div>
										
									</div>								

								<?php endif; ?>

								<?php if( $template == 'template3') : ?>

									<?php if( !empty( $icon ) && $show_background_quote == 'yes' ) : ?>
										<div class="quote">

											<i class="<?php echo esc_attr( $icon ); ?>"></i>

										</div>
									<?php endif; ?>

									<div class="author">
											
										<?php if( !empty( $items['author']['url']) ) : ?>
											<div class="image">

												<img src="<?php echo esc_url($items['author']['url']); ?>" alt="<?php echo esc_attr($image_alt); ?>">

											</div>
										<?php endif; ?>

									</div>

									<div class="info">

										<?php if( !empty( $items['name'] ) ) : ?>
											<h3 class="name"><?php echo esc_html($items['name']); ?></h3>
										<?php endif; ?>

										<?php if( !empty( $items['job'] ) ) : ?>
											<p class="job"><?php echo esc_html($items['job']); ?></p>
										<?php endif; ?>

										<?php if( !empty( $items['content'] ) ) : ?>
											<p class="content"><?php echo esc_html($items['content']); ?></p>
										<?php endif; ?>

										<?php if( $show_rating == 'yes') : ?>
											<div class="rating">
												<i aria-hidden="true" class="fas fa-star"></i>
												<i aria-hidden="true" class="fas fa-star"></i>
												<i aria-hidden="true" class="fas fa-star"></i>
												<i aria-hidden="true" class="fas fa-star"></i>
												<i aria-hidden="true" class="fas fa-star"></i>
											</div>
										<?php endif; ?>

									</div>

								<?php endif; ?>

							</div>

						<?php } ?>

					<?php } ?>

				</div>

			</div>

		<?php
	}
}
$widgets_manager->register( new Vedhak_Elementor_Testimonial() );