<?php

class Vedhak_Elementor {
	
	function __construct() {
            
		// Register Header Footer Category in Pane
	    add_action( 'elementor/elements/categories_registered', array( $this, 'vedhak_add_category' ) );

	    add_action( 'elementor/frontend/after_register_scripts', array( $this, 'vedhak_enqueue_scripts' ) );
		
		add_action( 'elementor/widgets/register', array( $this, 'vedhak_include_widgets' ) );
		
		add_filter( 'elementor/controls/animations/additional_animations', array( $this, 'vedhak_add_animations'), 10 , 0 );

		add_action( 'wp_print_footer_scripts', array( $this, 'vedhak_enqueue_footer_scripts' ) );

		// load icons
		add_filter( 'elementor/icons_manager/additional_tabs', array( $this, 'vedhak_icons_filters_new' ), 9999999, 1 );

		// customize social icon control style
		add_action( 'elementor/element/social-icons/section_social_hover/after_section_end', array( $this, 'vedhak_social_icons_custom' ), 10, 2 );

		// customize text editor control style
		add_action( 'elementor/element/text-editor/section_style/after_section_end', array( $this, 'vedhak_text_editor_custom' ), 10, 2 );

		// customize accordion control style
		add_action( 'elementor/element/accordion/section_toggle_style_content/after_section_end', array( $this, 'vedhak_accordion_custom' ), 10, 2 );

	}

	
	function vedhak_add_category(  ) {

	    \Elementor\Plugin::instance()->elements_manager->add_category(
	        'hf',
	        [
	            'title' => __( 'Header Footer', 'vedhak' ),
	            'icon' => 'fa fa-plug',
	        ]
	    );

	    \Elementor\Plugin::instance()->elements_manager->add_category(
	        'vedhak',
	        [
	            'title' => __( 'Vedhak', 'vedhak' ),
	            'icon' => 'fa fa-plug',
	        ]
	    );

	}

	function vedhak_enqueue_scripts(){
        
        $files = glob(get_theme_file_path('/assets/js/elementor/*.js'));
        
        foreach ($files as $file) {
            $file_name = wp_basename($file);
            $handle    = str_replace(".js", '', $file_name);
            $src       = get_theme_file_uri('/assets/js/elementor/' . $file_name);
            if (file_exists($file)) {
                wp_register_script( 'vedhak-elementor-' . $handle, $src, ['jquery'], false, true );
            }
        }


	}

	function vedhak_include_widgets( $widgets_manager ) {
        $files = glob(get_theme_file_path('elementor/widgets/*.php'));
        foreach ($files as $file) {
            $file = get_theme_file_path('elementor/widgets/' . wp_basename($file));
            if (file_exists($file)) {
                require_once $file;
            }
        }
    }

    function vedhak_add_animations(){
    	$animations = array(
            'Vedhak' => array(
                'ova-move-up' 		=> esc_html__('Move Up', 'vedhak'),
                'ova-move-down' 	=> esc_html__( 'Move Down', 'vedhak' ),
                'ova-move-left'     => esc_html__('Move Left', 'vedhak'),
                'ova-move-right'    => esc_html__('Move Right', 'vedhak'),
                'ova-scale-up'      => esc_html__('Scale Up', 'vedhak'),
                'ova-flip'          => esc_html__('Flip', 'vedhak'),
                'ova-helix'         => esc_html__('Helix', 'vedhak'),
                'ova-popup'			=> esc_html__( 'PopUp','vedhak' )
            ),
        );

        return $animations;
    }

   

	function vedhak_enqueue_footer_scripts(){
		// Font Icon
	    wp_enqueue_style('ovaicon', VEDHAK_URI.'/assets/libs/ovaicon/font/ovaicon.css', array(), null);

	    // Flaticon
		wp_enqueue_style('ova-flaticon', VEDHAK_URI.'/assets/libs/flaticon/font/flaticon_qampin.css', array(), null);
	}
	
	

	public function vedhak_icons_filters_new( $tabs = array() ) {
		$newicons = [];

		$font_data['json_url'] = VEDHAK_URI.'/assets/libs/ovaicon/ovaicon.json';
		$font_data['name'] = 'ovaicon';

		$newicons[ $font_data['name'] ] = [
			'name'          => $font_data['name'],
			'label'         => esc_html__( 'Default', 'vedhak' ),
			'url'           => '',
			'enqueue'       => '',
			'prefix'        => 'ovaicon-',
			'displayPrefix' => '',
			'ver'           => '1.0',
			'fetchJson'     => $font_data['json_url'],
		];

		$flaticon['json_url'] 	= VEDHAK_URI.'/assets/libs/flaticon/flaticon.json';
		$flaticon['name'] 		= 'flaticon';

		$newicons[ $flaticon['name'] ] = [
			'name'          => $flaticon['name'],
			'label'         => esc_html__( 'Flaticon', 'vedhak' ),
			'url'           => '',
			'enqueue'       => '',
			'prefix'        => 'flaticon-',
			'displayPrefix' => '',
			'ver'           => '1.0',
			'fetchJson'     => $flaticon['json_url'],
		];

		return array_merge( $tabs, $newicons );
	}

	// text-editor custom 
    function vedhak_text_editor_custom( $element, $args ) {
		/** @var \Elementor\Element_Base $element */
		$element->start_controls_section(
			'ova_tabs',
			[
				'tab' 	=> \Elementor\Controls_Manager::TAB_STYLE,
				'label' => esc_html__( 'Ova Text Editor', 'vedhak' ),
			]
		);

		   $element->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'link_typography',
					'selector' => '{{WRAPPER}} a',
				]
			);
            
            $element->add_control(
	            'link_color',
	            [
	                'label' 	=> esc_html__( 'Link Color', 'vedhak' ),
	                'type' 		=> \Elementor\Controls_Manager::COLOR,
	                'selectors' => [
	                    '{{WRAPPER}} a' => 'color: {{VALUE}};',
	                ],
	            ]
	        );

	        $element->add_control(
	            'link_color_hover',
	            [
	                'label' 	=> esc_html__( 'Link Color Hover', 'vedhak' ),
	                'type' 		=> \Elementor\Controls_Manager::COLOR,
	                'selectors' => [
	                    '{{WRAPPER}} a:hover' => 'color: {{VALUE}};',
	                ],
	            ]
	        );

			$element->add_responsive_control(
				'text_margin',
				[
					'label' 		=> esc_html__( 'Margin', 'vedhak' ),
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' 	=> [ 'px', '%', 'em' ],
					'selectors' 	=> [
					'{{WRAPPER}} p' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$element->add_responsive_control(
		        'text_padding',
		        [
		            'label' 		=> esc_html__( 'Padding', 'vedhak' ),
		            'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
		            'size_units' 	=> [ 'px', '%', 'em' ],
		            'selectors' 	=> [
		             '{{WRAPPER}}  p' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
		            ],
		         ]
		    );


		$element->end_controls_section();
	}
	

	function vedhak_social_icons_custom ( $element, $args ) {
		/** @var \Elementor\Element_Base $element */
		$element->start_controls_section(
			'ova_social_icons',
			[
				'tab' 	=> \Elementor\Controls_Manager::TAB_STYLE,
				'label' => esc_html__( 'Ova Social Icon', 'vedhak' ),
			]
		);

			$element->add_responsive_control(
	            'ova_social_icons_display',
	            [
	                'label' 	=> esc_html__( 'Display', 'vedhak' ),
	                'type' 		=> \Elementor\Controls_Manager::CHOOSE,
	                'options' 	=> [
	                    'inline-block' => [
	                        'title' => esc_html__( 'Block', 'vedhak' ),
	                        'icon' 	=> 'eicon-h-align-left',
	                    ],
	                    'inline-flex' => [
	                        'title' => esc_html__( 'Flex', 'vedhak' ),
	                        'icon' 	=> 'eicon-h-align-center',
	                    ],
	                ],
	                'selectors' => [
	                    '{{WRAPPER}} .elementor-icon.elementor-social-icon' => 'display: {{VALUE}}',
	                ],
	            ]
	        );

		$element->end_controls_section();
	}


	function vedhak_accordion_custom( $element, $args ) {
		/** @var \Elementor\Element_Base $element */
		$element->start_controls_section(
			'ova_accordion',
			[
				'tab' 	=> \Elementor\Controls_Manager::TAB_STYLE,
				'label' => esc_html__( 'Ova Accordion', 'vedhak' ),
			]
		); 

			$element->add_control(
				'title_heading',
				[
					'label' => esc_html__( 'Title', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

			$element->add_group_control(
				\Elementor\Group_Control_Border::get_type(),
				[
					'name' => 'title_border',
					'selector' => '{{WRAPPER}} .elementor-accordion .elementor-tab-title , {{WRAPPER}} .elementor-accordion .elementor-tab-title.elementor-active', 
				]
			);

			$element->add_control(
				'border_color_title_active',
				[
					'label' => esc_html__( 'Title Active Border Color', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .elementor-accordion .elementor-tab-title.elementor-active' => 'border-color: {{VALUE}}',
					],
				]
			);

			$element->add_control(
				'icon_heading',
				[
					'label' => esc_html__( 'Icon', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

			$element->add_responsive_control(
				'icon_size',
				[
					'label' => esc_html__( 'Size', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 100,
							'step' => 1,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .elementor-accordion .elementor-tab-title .elementor-accordion-icon' => 'font-size: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$element->add_responsive_control(
				'icon_margin',
				[
					'label' => esc_html__( 'Margin', 'vedhak' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'selectors' => [
						'{{WRAPPER}} .elementor-accordion .elementor-tab-title .elementor-accordion-icon' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$element->end_controls_section();  
	}
}

return new Vedhak_Elementor();