<?php
/**
 * @package    Vedhak by ovatheme
 * @author     Ovatheme
 * @copyright  Copyright (C) 2022 Ovatheme All Rights Reserved.
 * @license    GNU/GPL v2 or later http://www.gnu.org/licenses/gpl-2.0.html
 */

if ( !defined( 'ABSPATH' ) ) exit();

$product_id 	= isset( $args['id'] ) && $args['id'] ? $args['id'] : get_the_id();
$product 		= wc_get_product( $product_id );

$short_desc 	= vedhak_custom_text( $product->get_short_description(), 10 );

$date_format    = ovabrw_get_date_format();

$min_guest      = get_post_meta( $product_id, 'ovabrw_guest_min', true );
if ( !$min_guest ) {
	$min_guest  = 1;
}

// thumbnail
$link      	= apply_filters( 'woocommerce_loop_product_link', get_the_permalink(), $product );
$param      = array();


global $_POST;
$clicked 		= isset( $_POST['clicked'] ) 	? $_POST['clicked'] 	: '';
$start_date 	= isset( $_POST['start_date'] ) ? $_POST['start_date'] 	: '';
$end_date 		= isset( $_POST['end_date'] ) 	? $_POST['end_date'] 	: '';
$guests 		= isset( $_POST['guests'] ) 	? $_POST['guests'] 		: $min_guest;

$dropoff_date 	= '';

if($clicked) {
	if ( $start_date ) {
		$param['pickup_date'] 	= $start_date;
	}

	if ( $end_date ) {
		$param['pickoff_date']  = $end_date;
	}

	if ( $guests ) {
		$param['ovabrw_guests'] = $guests;
	}

	if ( $param ) {
		$link = add_query_arg( $param, $link );
	}
}


// Star Rating
$review_count   = $product->get_review_count();
$rating         = $product->get_average_rating();

// Features
$features_icons = get_post_meta( $product_id, 'ovabrw_features_icons', true );

?>

<div class="ova_head_product">
	<a href="<?php echo esc_url( $link ); ?>" class="ova-product-thumbnail">
		<?php echo woocommerce_get_product_thumbnail('vedhak_thumbnail'); ?>
	</a>
	<div class="shape"></div>
	<a href="<?php echo esc_url( $link ); ?>" class="product-view-detail">
		<i aria-hidden="true" class="fas fa-arrow-right"></i>
	</a>
</div>

<div class="ova_foot_product">

	<div class="product-info">
        
        <?php if ( $review_count > 0 ): ?>
			<div class="star-rating" role="img" aria-label="<?php echo sprintf( __( 'Rated %s out of 5', 'vedhak' ), $rating ); ?>">
	            <span class="rating-percent" style="width: <?php echo esc_attr( ( $rating / 5 ) * 100 ).'%'; ?>;"></span>
	        </div>
         <?php endif; ?>
		
		<h2 class="ova-product-title">
			<a href="<?php echo esc_url( $link ); ?>">
		        <?php echo get_the_title(); ?>
		    </a>
		</h2>
        
        <?php if( !empty($short_desc) ) { ?>
			<p class="product-short-desc">
				<?php echo esc_html($short_desc);?>
			</p>
		<?php } ?>

		<div class="feature-icon-and-link">
			<?php if( !empty( $features_icons ) && is_array($features_icons) ) { ?>
				<div class="feature-icon-wrapper">
					<?php for( $i = 0; $i < count( $features_icons ) - 1; $i++ ): ?>
			            <div class="feature-icon">
			                <?php if ( isset( $features_icons[$i] ) && is_array($features_icons[$i]) ): ?>
			                    <?php foreach( $features_icons[$i] as $key => $value ): if($key>1) break;?>
			                        <i aria-hidden="true" class="<?php echo esc_attr( isset($features_icons[$i][$key]) ? $features_icons[$i][$key] : '' ); ?>"></i>
			                    <?php endforeach; ?>
			                <?php endif; ?>
			            </div>
			        <?php endfor; ?>
				</div>
			<?php } ?>

			<a href="<?php echo esc_url( $link ); ?>" class="product-view-detail">
				<i aria-hidden="true" class="fas fa-arrow-right"></i>
			</a>
		</div>
	    
	</div>

</div>