<?php
/**
 * @package    Vedhak by ovatheme
 * @author     Ovatheme
 * @copyright  Copyright (C) 2022 Ovatheme All Rights Reserved.
 * @license    GNU/GPL v2 or later http://www.gnu.org/licenses/gpl-2.0.html
 */

if ( !defined( 'ABSPATH' ) ) exit();

$product_id = isset( $args['id'] ) && $args['id'] ? $args['id'] : get_the_id();

$product = wc_get_product( $product_id );

if ( !$product || !$product->is_type('ovabrw_car_rental') ) return;

// Get first day in week
$first_day = get_option( 'ova_brw_calendar_first_day', '0' );

if ( empty( $first_day ) ) {
    $first_day = 0;
}

$disable_week_day = get_post_meta( $product_id, 'ovabrw_product_disable_week_day', true );

// Total Day
$total_day = get_post_meta( $product_id, 'ovabrw_number_days', true );
if ( ! $total_day ) {
    $total_day = 1;
}


$ovabrw_rental_type     = get_post_meta( $product_id, 'ovabrw_price_type', true ); 
$defined_one_day        = defined_one_day( $product_id );

$time_to_book_start     = ovabrw_time_to_book( $product_id, 'start' );
$time_to_book_end       = ovabrw_time_to_book( $product_id, 'end' );

$default_hour_start     = ovabrw_get_default_time( $product_id, 'start' );
$default_hour_end       = ovabrw_get_default_time( $product_id, 'end' );

$timepicker_start       = ovabrw_timepicker_product( $product_id, 'start' );
$timepicker_end         = ovabrw_timepicker_product( $product_id, 'end' );

// Get booked time
$statuses   = brw_list_order_status();
$order_time = get_order_rent_time( $product_id, $statuses );

$placeholder_date   = ovabrw_get_placeholder_date();
$label_package      = esc_html__( 'Package', 'vedhak' );

// Get categories
$terms = wp_get_post_terms( $product_id,'product_cat',array('fields'=>'ids') );
if ( $terms && is_array( $terms ) ) {
    $term_id = reset($terms);
}

// Get label pick-up and pick-off date ( check in, check out)
$label_pickup_date          = esc_html__( 'Check in', 'vedhak');
$setting_lable_pickup_date  = get_post_meta( $product_id, 'ovabrw_label_pickup_date_product', true );

if ( $setting_lable_pickup_date == 'new' ) {
    $label_pickup_date = get_post_meta( $product_id, 'ovabrw_new_pickup_date_product', true );
} elseif ( $setting_lable_pickup_date == 'category' ) {
    $label_pickup_date  = isset( $term_id ) ? get_term_meta( $term_id, 'ovabrw_lable_pickup_date', true ) : esc_html__( 'Check in', 'vedhak');
} else {
    $label_pickup_date = esc_html__( 'Check in', 'vedhak');
}

$label_dropoff_date         = esc_html__( 'Check out', 'vedhak');
$setting_lable_dropoff_date = get_post_meta( $product_id, 'ovabrw_label_dropoff_date_product', true );

if ( $setting_lable_dropoff_date == 'new' ) {
    $label_dropoff_date = get_post_meta( $product_id, 'ovabrw_new_dropoff_date_product', true );
} elseif ( $setting_lable_dropoff_date == 'category' ) {
    $label_dropoff_date = isset( $term_id ) ? get_term_meta( $term_id, 'ovabrw_lable_dropoff_date', true ) : esc_html__( 'Check out', 'vedhak');
} else {
    $label_dropoff_date = esc_html__( 'Check out', 'vedhak');
}

if ( $label_pickup_date == '' ) {
    $label_pickup_date = esc_html__( 'Check in', 'vedhak');
}
if ( $label_dropoff_date == '' ) {
    $label_dropoff_date = esc_html__( 'Check out', 'vedhak');
}

$choose_hour_pickup     = $timepicker_start ? 'yes' : 'no';
$choose_hour_dropoff    = $timepicker_end   ? 'yes' : 'no';

$check_in_default   = ovabrw_get_current_date_from_search( $choose_hour_pickup, 'pickup_date', $product_id );
$check_out_default  = ovabrw_get_current_date_from_search( $choose_hour_dropoff, 'dropoff_date', $product_id );

// Show/Hide checkout field
$show_checkout = get_option( 'ova_brw_booking_form_show_dropoff_date', 'yes' );

// Period of Time
$period_time_class = '';

if ( $ovabrw_rental_type == 'period_time' ) {
    $period_time_class = ' start_date_perido_time';

    $unfixed_time = get_post_meta( $product_id, 'ovabrw_unfixed_time', true );

    if ( $unfixed_time == 'yes' ) {
        $timepicker_start = 'true';
    } else {
        $timepicker_start = 'false';
    }
}

?>

<div class="rental_item ovabrw_checkin_field">
    <label>
        <?php echo esc_html( $label_pickup_date ); ?>
    </label>
    <input 
        type="text" 
        name="ovabrw_pickup_date"  
        data-default_hour="<?php echo esc_attr( $default_hour_start ); ?>"  
        data-time_to_book="<?php echo esc_attr( $time_to_book_start ); ?>" 
        class="required ovabrw_datetimepicker ovabrw_start_date<?php echo esc_attr( $period_time_class ); ?>" 
        placeholder="<?php echo esc_attr( $placeholder_date ); ?>" 
        autocomplete="off" 
        value="<?php echo esc_attr( $check_in_default ); ?>" 
        data-firstday="<?php echo esc_attr( $first_day ); ?>" 
        data-disable-week-day="<?php echo esc_attr( $disable_week_day ); ?>" 
        data-total-day="<?php echo esc_attr( $total_day ); ?>" 
        data-order-time='<?php echo esc_attr( $order_time ); ?>' 
        data-error="<?php esc_html_e( 'Check in is required.', 'vedhak' ); ?>" 
        timepicker='<?php echo esc_attr( $timepicker_start ); ?>' />
    <span class="ovabrw-date-loading">
        <i aria-hidden="true" class="fas fa-spinner"></i>
    </span>
</div>

<!-- Check Rental type -->
<?php if ( $ovabrw_rental_type == 'period_time'): 
    $ovabrw_petime_id       = get_post_meta( $id, 'ovabrw_petime_id', true );
    $ovabrw_petime_label    = get_post_meta( $id, 'ovabrw_petime_label', true );
?>
    <div class="rental_item">
        <label>
            <?php echo esc_html( $label_package ); ?>
        </label>
        <div class="period_package">
            <select name="ovabrw_period_package_id" id="ovabrw_package" class="required">
                <option value=""><?php esc_html_e( 'Select Package', 'vedhak' ); ?></option>
                <?php if ( $ovabrw_petime_id ): ?>
                    <?php foreach ( $ovabrw_petime_id as $key => $value ): ?>
                        <?php if ( isset( $ovabrw_petime_id[$key] ) && isset( $ovabrw_petime_label[$key] ) ): ?>
                            <option value="<?php echo esc_attr(trim( $ovabrw_petime_id[$key] ) ); ?>" > 
                                <?php echo esc_html( $ovabrw_petime_label[$key] ); ?> 
                            </option>
                        <?php endif; ?>
                    <?php endforeach; ?>
                <?php endif; ?>
            </select>
        </div>
    </div>
<?php elseif ($ovabrw_rental_type != 'transportation' ): ?>
    <?php if ( $show_checkout ): ?>
        <div class="rental_item">
            <label>
                <?php echo esc_html( $label_dropoff_date ); ?>
            </label>
            <input 
                type="text" 
                name="ovabrw_pickoff_date" 
                data-default_hour="<?php echo esc_attr( $default_hour_end ); ?>"  
                data-time_to_book="<?php echo esc_attr( $time_to_book_end ); ?>"  
                class="required ovabrw_datetimepicker ovabrw_end_date" 
                placeholder="<?php echo esc_attr( $placeholder_date ); ?>"   
                autocomplete="off" 
                value="<?php echo esc_attr( $check_out_default ); ?>"   
                data-order-time='<?php echo esc_attr( $order_time ); ?>' 
                data-firstday='<?php echo esc_attr( $first_day ); ?>' 
                data-error="<?php esc_html_e( 'Check out is required.', 'vedhak' ); ?>" 
                timepicker='<?php echo esc_attr( $timepicker_end ); ?>' 
                onfocus="blur();" />
            <span class="ovabrw-date-loading">
                <i aria-hidden="true" class="fas fa-spinner"></i>
            </span>
        </div>
    <?php endif; ?>
<?php endif; ?>